(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     98462,       3549]
NotebookOptionsPosition[     77838,       2957]
NotebookOutlinePosition[     80653,       3035]
CellTagsIndexPosition[     80312,       3024]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Expressions"
}], "Title"],

Cell[CellGroupData[{

Cell["What Is An Expression?", "Section"],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 " everything is an ",
 StyleBox["expression",
  FontSlant->"Italic"],
 ". The command ",
 Cell[BoxData[
  ButtonBox["FullForm",
   BaseStyle->"RefGuideLink"]]],
 "  shows the internal structure of all ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expressions. "
}], "Text"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}], "]"}]], "Input"],

Cell[TextData[{
 "Every expression has a \"Head\", which refers to the ",
 StyleBox["type",
  FontSlant->"Italic"],
 " of the expression."
}], "Text"],

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"a", "==", "b"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"x", "\[Rule]", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", "100", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", "100.2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", 
  FractionBox["100", "3"], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", "a", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Head", "[", "\"\<100a\>\"", "]"}]], "Input"],

Cell[TextData[{
 "Even ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["commands",
  FontSlant->"Italic"],
 " are represented as expressions, e.g."
}], "Text"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"Hold", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], "-", "3"}], "\[Equal]", "4"}], ",", "x"}], 
    "]"}], "]"}], "]"}]], "Input"],

Cell["\<\
only that many commands have some \"nice syntax\" that hides the internal \
form of the expression, e.g.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"Hold", "[", 
   RowBox[{
    SuperscriptBox["x", "2"], "/.", 
    RowBox[{"x", "\[Rule]", "a"}]}], "]"}], "]"}]], "Input"],

Cell[TextData[{
 "We already see here: For ",
 StyleBox["commands",
  FontSlant->"Italic"],
 " we need to prevent ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " from immediately executing the command before it can show its internal \
form by wrapping the command into ",
 Cell[BoxData[
  ButtonBox["Hold",
   BaseStyle->"RefGuideLink"]]],
 ". Otherwise, we would only see the internal form only of the result!"
}], "Text"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{
   SuperscriptBox["x", "2"], "/.", 
   RowBox[{"x", "\[Rule]", "a"}]}], "]"}]], "Input"],

Cell["We will see more details in the subsequent sections.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evaluation of Expressions", "Section"],

Cell[TextData[{
 "The driving engine of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is the ",
 StyleBox["evaluation of expressions",
  FontSlant->"Italic"],
 ". This is, actually, what happens when you type ",
 "\[ShiftKey]+\[ReturnIndicator]",
 " in a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " input cell: The expression in the current input cell is sent to the kernel \
for evaluation.\n\"Evaluation\" means rewriting the expression w.r.t. user\
\[Dash]defined oder built\[Dash]in definitions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", "*", "5"}], "+", 
    RowBox[{"Sin", "[", "\[Pi]", "]"}]}], ")"}], 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"15", " ", 
  RowBox[{"f", "[", 
   RowBox[{"8", ",", "x"}], "]"}]}]], "Output",
 CellChangeTimes->{3.480151151356782*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", "*", "5"}], "+", 
      RowBox[{"Sin", "[", "\[Pi]", "]"}]}], ")"}], 
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]}], "]"}], "//", 
  "FullForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Hold", "[", 
    RowBox[{"Times", "[", 
     RowBox[{
      RowBox[{"Plus", "[", 
       RowBox[{
        RowBox[{"Times", "[", 
         RowBox[{"3", ",", "5"}], "]"}], ",", 
        RowBox[{"Sin", "[", "Pi", "]"}]}], "]"}], ",", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"Plus", "[", 
         RowBox[{"3", ",", "5"}], "]"}], ",", "x"}], "]"}]}], "]"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{3.480151257919558*^9}]
}, Open  ]],

Cell[TextData[{
 "There are built\[Dash]in definitions for ",
 StyleBox["Times", "Input"],
 " and ",
 StyleBox["Sin", "Input"],
 " that rewrite ",
 StyleBox["3*5", "Input"],
 " to 15 and ",
 StyleBox["Sin[\[Pi]]", "Input"],
 " to 0, then there is a built\[Dash]in definition for ",
 StyleBox["Plus", "Input"],
 " that rewrites ",
 StyleBox["15+0", "Input"],
 " to 15. Similarly, ",
 StyleBox["3+5", "Input"],
 " rewrites to 8. Since there is no definiton for ",
 StyleBox["f[8,x]", "Input"],
 ", the final result is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"15", 
    RowBox[{"f", "[", 
     RowBox[{"8", ",", "x"}], "]"}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", "*", "5"}], "+", 
     RowBox[{"Sin", "[", "\[Pi]", "]"}]}], ")"}], 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]}], "//", "Trace"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       TagBox[
        RowBox[{"3", " ", "5"}],
        HoldForm], ",", 
       TagBox["15",
        HoldForm]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       TagBox[
        RowBox[{"Sin", "[", "\[Pi]", "]"}],
        HoldForm], ",", 
       TagBox["0",
        HoldForm]}], "}"}], ",", 
     TagBox[
      RowBox[{"15", "+", "0"}],
      HoldForm], ",", 
     TagBox["15",
      HoldForm]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       TagBox[
        RowBox[{"3", "+", "5"}],
        HoldForm], ",", 
       TagBox["8",
        HoldForm]}], "}"}], ",", 
     TagBox[
      RowBox[{"f", "[", 
       RowBox[{"8", ",", "x"}], "]"}],
      HoldForm]}], "}"}], ",", 
   TagBox[
    RowBox[{"15", " ", 
     RowBox[{"f", "[", 
      RowBox[{"8", ",", "x"}], "]"}]}],
    HoldForm]}], "}"}]], "Output",
 CellChangeTimes->{3.480151335253182*^9}]
}, Open  ]],

Cell[TextData[{
 "As we see in the example above, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " first evaluates the subexpressions and then evaluates the resulting \
expression. Of course, in each subexpression this process is continued \
recursively. The process stops when there is no definition anymore that can \
be applied to the expression. In the example, evaluating the first \
subexpression stopped at 15,  the second subexpression ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"3", "+", "5"}], ",", "x"}], "]"}], TraditionalForm]]],
 " evaluated to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", 
    RowBox[{"8", ",", "x"}], "]"}], TraditionalForm]]],
 ", which did not change further, because there is neither a definition for \
",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " nor a definition for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", 
    RowBox[{"8", ",", "x"}], "]"}], TraditionalForm]]],
 ", thus resulting in the expression ",
 Cell[BoxData[
  FormBox[
   RowBox[{"15", "*", 
    RowBox[{"f", "[", 
     RowBox[{"8", ",", "x"}], "]"}]}], TraditionalForm]]],
 ". Since there is no definition for ",
 StyleBox["Times", "Input"],
 " that can be used for rewriting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"15", "*", 
    RowBox[{"f", "[", 
     RowBox[{"8", ",", "x"}], "]"}]}], TraditionalForm]]],
 " the evaluation stops and the ",
 StyleBox["result of this evaluation",
  FontSlant->"Italic"],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"15", "*", 
    RowBox[{"f", "[", 
     RowBox[{"8", ",", "x"}], "]"}]}], TraditionalForm]]],
 ". \nWe can, however, give definitions for ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " and/or ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "=", "2"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", "*", "5"}], "+", 
    RowBox[{"Sin", "[", "\[Pi]", "]"}]}], ")"}], 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"15", " ", 
  RowBox[{"f", "[", 
   RowBox[{"8", ",", "2"}], "]"}]}]], "Output",
 CellChangeTimes->{3.480151722405549*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"8", ",", "2"}], "]"}], "=", "3"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", "*", "5"}], "+", 
    RowBox[{"Sin", "[", "\[Pi]", "]"}]}], ")"}], 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]}]], "Input"],

Cell[BoxData["45"], "Output",
 CellChangeTimes->{3.48015177023009*^9}]
}, Open  ]],

Cell[TextData[{
 "Both ",
 StyleBox["commands",
  FontSlant->"Italic"],
 " and ",
 StyleBox["data",
  FontSlant->"Italic"],
 " are just ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expressions! Expressions, for which there is a definition, behave like \
commands. Expressions, for which there is no definition, behave like data.\n\
Commands:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sin", "[", "\[Pi]", "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.48015204938129*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"8", ",", "2"}], "]"}]], "Input"],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.480152057274149*^9}]
}, Open  ]],

Cell["Data:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"List", "[", 
   RowBox[{"1", ",", "2"}], "]"}], "//", "FullForm"}]], "Input",
 CellChangeTimes->{{3.480152087534022*^9, 3.480152089607626*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"List", "[", 
    RowBox[{"1", ",", "2"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{{3.480152070505479*^9, 3.480152090202257*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Output",
 CellChangeTimes->{3.480152116511454*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attributes", "Section"],

Cell["Attributes may influence the evaluation of expressions.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.480152265922315*^9}]
}, Open  ]],

Cell[TextData[{
 "In this setup, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " performs \"call by value\" in function calls."
}], "Text"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "HoldFirst"}], "]"}]], "Input"],

Cell[TextData[{
 "Use ",
 StyleBox["?f", "Input"],
 " for inspecting the user\[Dash]definitions available for ",
 StyleBox["f", "Input"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell["Global`f", "Print", "PrintUsage",
 CellChangeTimes->{3.480152305316145*^9},
 CellTags->"Info3480159505-1242375"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "f", "]"}], "=", 
      RowBox[{"{", "HoldFirst", "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"8", ",", "2"}], "]"}], "=", "3"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`f],
  Editable->False]], "Print",
 CellChangeTimes->{3.480152305380073*^9},
 CellTags->"Info3480159505-1242375"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trace", "[", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", "x"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TagBox["x",
      HoldForm], ",", 
     TagBox["2",
      HoldForm]}], "}"}], ",", 
   TagBox[
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"3", "+", "5"}], ",", "2"}], "]"}],
    HoldForm]}], "}"}]], "Output",
 CellChangeTimes->{3.480152327930161*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"3", "+", "5"}], ",", "2"}], "]"}]], "Output",
 CellChangeTimes->{3.480152409966133*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ClearAttributes", "[", 
  RowBox[{"f", ",", "HoldFirst"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "HoldRest"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell["Global`f", "Print", "PrintUsage",
 CellChangeTimes->{3.480152815074106*^9},
 CellTags->"Info3480160014-9080128"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "f", "]"}], "=", 
      RowBox[{"{", "HoldRest", "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"8", ",", "2"}], "]"}], "=", "3"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`f],
  Editable->False]], "Print",
 CellChangeTimes->{3.480152815108551*^9},
 CellTags->"Info3480160014-9080128"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trace", "[", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", "x"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TagBox[
      RowBox[{"3", "+", "5"}],
      HoldForm], ",", 
     TagBox["8",
      HoldForm]}], "}"}], ",", 
   TagBox[
    RowBox[{"f", "[", 
     RowBox[{"8", ",", "x"}], "]"}],
    HoldForm]}], "}"}]], "Output",
 CellChangeTimes->{3.480152817812954*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "HoldFirst"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell["Global`f", "Print", "PrintUsage",
 CellChangeTimes->{3.480152873846622*^9},
 CellTags->"Info3480160073-5738855"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "f", "]"}], "=", 
      RowBox[{"{", "HoldAll", "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"8", ",", "2"}], "]"}], "=", "3"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`f],
  Editable->False]], "Print",
 CellChangeTimes->{3.480152873882819*^9},
 CellTags->"Info3480160073-5738855"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ClearAttributes", "[", 
  RowBox[{"f", ",", "HoldRest"}], "]"}]], "Input",
 CellChangeTimes->{{3.480152936547817*^9, 3.480152944240156*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input",
 CellChangeTimes->{{3.480152947920967*^9, 3.480152948289457*^9}}],

Cell["Global`f", "Print", "PrintUsage",
 CellChangeTimes->{3.480152949736085*^9},
 CellTags->"Info3480160149-4147071"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "f", "]"}], "=", 
      RowBox[{"{", "HoldAll", "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"8", ",", "2"}], "]"}], "=", "3"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`f],
  Editable->False]], "Print",
 CellChangeTimes->{3.480152949815844*^9},
 CellTags->"Info3480160149-4147071"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Trace", "[", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", "x"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"3", "+", "5"}], ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "Listable"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[BoxData[
 RowBox[{"Trace", "[", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "3"}], "}"}], ",", 
    RowBox[{"3", "+", "1"}]}], "]"}], "]"}]], "Input"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["Orderless",
   BaseStyle->"RefGuideLink"]]],
 " brings arguments into an internal default\[Dash]order before it evaluates \
the expression."
}], "Text"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "Orderless"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell["Global`f", "Print", "PrintUsage",
 CellChangeTimes->{3.480153105483177*^9},
 CellTags->"Info3480160305-1501528"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "f", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"HoldAll", ",", "Orderless"}], "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"8", ",", "2"}], "]"}], "=", "3"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`f],
  Editable->False]], "Print",
 CellChangeTimes->{3.480153105517234*^9},
 CellTags->"Info3480160305-1501528"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"8", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"2", ",", "8"}], "]"}]], "Output",
 CellChangeTimes->{3.480153110153969*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"x", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"2", ",", "x"}], "]"}]], "Output",
 CellChangeTimes->{3.480153171881178*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["Flat",
   BaseStyle->"RefGuideLink"]]],
 " flattens nested expressions."
}], "Text"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "Flat"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"8", ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "6"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"2", ",", "6", ",", "8"}], "]"}]], "Output",
 CellChangeTimes->{3.480153245406863*^9}]
}, Open  ]],

Cell[TextData[{
 "Further attributes can be found in the ",
 ButtonBox["manual",
  BaseStyle->"MasterIndexLink",
  ButtonData:>"Attributes"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Explicit Evaluation or Non\[Dash]Evaluation Depsite of Attributes\
\>", "Subsection"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["ClearAll",
   BaseStyle->"RefGuideLink"]]],
 " clears the definitions and all attributes as well."
}], "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[TextData[{
 "The first possibility to keep a parameter unevaluated is to wrap it into ",
 Cell[BoxData[
  ButtonBox["Unevaluated",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_Plus", "]"}], ":=", 
  RowBox[{"\"\<The sum expression is: \>\"", "<>", 
   RowBox[{"ToString", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.480154111451052*^9, 3.480154115916285*^9}, 
   3.480154164854781*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{"\"\<The parameter is: \>\"", "<>", 
   RowBox[{"ToString", "[", "x", "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"x", "+", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.480153474152582*^9, 3.48015347901723*^9}}],

Cell[BoxData["\<\"The sum expression is: 2 + y\"\>"], "Output",
 CellChangeTimes->{3.480153479489187*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"x", "+", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.480153535411641*^9, 3.480153540557296*^9}}],

Cell[BoxData["\<\"The parameter is: 5\"\>"], "Output",
 CellChangeTimes->{3.480153541464186*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"Unevaluated", "[", 
   RowBox[{"5", "+", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData["\<\"The sum expression is: 5 + 3\"\>"], "Output",
 CellChangeTimes->{3.480153681315843*^9, 3.480154148193354*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "ToString", "]"}]], "Input",
 CellChangeTimes->{{3.480153899919293*^9, 3.48015390448901*^9}}],

Cell[BoxData[
 RowBox[{"{", "Protected", "}"}]], "Output",
 CellChangeTimes->{3.480153905129582*^9}]
}, Open  ]],

Cell[TextData[{
 "What we see is that ",
 StyleBox["Unevaluated", "Input"],
 " keeps the parameter unevaluated in the call to ",
 StyleBox["f", "Input"],
 ", but in further evaluations the passed parameter is evaluated. The \
stronger form is ",
 Cell[BoxData[
  ButtonBox["Hold",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"Hold", "[", 
   RowBox[{"5", "+", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData["\<\"The parameter is: Hold[5 + 3]\"\>"], "Output",
 CellChangeTimes->{3.480154219384936*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{
   RowBox[{"Hold", "[", 
    RowBox[{"3", "+", "5"}], "]"}], ",", 
   RowBox[{"Hold", "[", 
    RowBox[{"3", "+", "98"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480154331993739*^9, 3.480154364582254*^9}}],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{
   RowBox[{"Hold", "[", 
    RowBox[{"3", "+", "5"}], "]"}], ",", 
   RowBox[{"Hold", "[", 
    RowBox[{"3", "+", "98"}], "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.480154365274032*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReleaseHold", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.480154401082048*^9, 3.480154410503944*^9}}],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{"8", ",", "101"}], "]"}]], "Output",
 CellChangeTimes->{3.480154411423569*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Hold", "Input"],
 " effectively forms a new expression and all parts inside ",
 StyleBox["Hold", "Input"],
 " are kept unevaluated.\n",
 Cell[BoxData[
  ButtonBox["Evaluate",
   BaseStyle->"RefGuideLink"]]],
 " can be used to evaluate parameters in the presence of \
Hold\[Dash]Attributes."
}], "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "HoldFirst"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_Plus", "]"}], ":=", 
  RowBox[{"\"\<The sum expression is: \>\"", "<>", 
   RowBox[{"ToString", "[", 
    RowBox[{"Unevaluated", "[", "x", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{"\"\<The parameter is: \>\"", "<>", 
   RowBox[{"ToString", "[", "x", "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", "+", "5"}], "]"}]], "Input"],

Cell[BoxData["\<\"The sum expression is: 3 + 5\"\>"], "Output",
 CellChangeTimes->{3.480154641392377*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"3", "+", "5"}], "]"}], "]"}]], "Input"],

Cell[BoxData["\<\"The parameter is: 8\"\>"], "Output",
 CellChangeTimes->{3.480154697937845*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"ToString", ",", "HoldFirst"}], "]"}]], "Input",
 CellChangeTimes->{{3.480155011230007*^9, 3.480155029235091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "ToString"}]], "Input",
 CellChangeTimes->{{3.480155035605475*^9, 3.480155043134223*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"ToString\\\", \\\"[\\\", \
StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\"]\\\"}]\\) gives a string \
corresponding to the printed form of \\!\\(\\*StyleBox[\\\"expr\\\", \\\"TI\\\
\"]\\) in OutputForm. \\n\\!\\(\\*RowBox[{\\\"ToString\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"form\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) gives the string corresponding to output in the \
specified form. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ToString"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.480155044319706*^9},
 CellTags->
  "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "ToString", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"HoldFirst", ",", "Protected"}], "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"Options", "[", "ToString", "]"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CharacterEncoding", "\[Rule]", "\<\"Unicode\"\>"}], ",", 
           RowBox[{"FormatType", "\[Rule]", "\<\"OutputForm\"\>"}], ",", 
           RowBox[{"NumberMarks", "\[RuleDelayed]", "$NumberMarks"}], ",", 
           RowBox[{"PageHeight", "\[Rule]", "\[Infinity]"}], ",", 
           RowBox[{"PageWidth", "\[Rule]", "\[Infinity]"}], ",", 
           RowBox[{"TotalHeight", "\[Rule]", "\[Infinity]"}], ",", 
           RowBox[{"TotalWidth", "\[Rule]", "\[Infinity]"}]}], "}"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[ToString],
  Editable->False]], "Print",
 CellChangeTimes->{3.480155044448207*^9},
 CellTags->
  "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "Plot"}]], "Input",
 CellChangeTimes->{{3.480155175277778*^9, 3.480155176451221*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Plot\\\", \\\"[\\\", RowBox[{StyleBox[\\\
\"f\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) generates \
a plot of \\!\\(\\*StyleBox[\\\"f\\\", \\\"TI\\\"]\\) as a function of \\!\\(\
\\*StyleBox[\\\"x\\\", \\\"TI\\\"]\\) from \
\\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]]\\) to \\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]\\). \\n\\!\\(\\*RowBox[{\\\"Plot\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"f\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"f\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) plots \
several functions \\!\\(\\*SubscriptBox[StyleBox[\\\"f\\\", \\\"TI\\\"], \
StyleBox[\\\"i\\\", \\\"TI\\\"]]\\). \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.480155177530078*^9},
 CellTags->
  "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "Plot", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"HoldAll", ",", "Protected"}], "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"Options", "[", "Plot", "]"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"AlignmentPoint", "\[Rule]", "Center"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", 
            FractionBox["1", "GoldenRatio"]}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", "None"}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"AxesStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"Background", "\[Rule]", "None"}], ",", 
           RowBox[{"BaselinePosition", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"BaseStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}], ",", 
           RowBox[{"ColorOutput", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"ContentSelectable", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"CoordinatesToolOptions", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"DisplayFunction", "\[RuleDelayed]", "$DisplayFunction"}], 
           ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"Evaluated", "\[Rule]", "System`Private`$Evaluated"}], ",", 
           RowBox[{"EvaluationMonitor", "\[Rule]", "None"}], ",", 
           RowBox[{"Exclusions", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"ExclusionsStyle", "\[Rule]", "None"}], ",", 
           RowBox[{"Filling", "\[Rule]", "None"}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", "Automatic"}], ",", 
           RowBox[{
           "FormatType", "\[RuleDelayed]", "\<\"TraditionalForm\"\>"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", "None"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"FrameTicksStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"GridLines", "\[Rule]", "None"}], ",", 
           RowBox[{"GridLinesStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"ImageMargins", "\[Rule]", "0.`"}], ",", 
           RowBox[{"ImagePadding", "\[Rule]", "All"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"ImageSizeRaw", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"MaxRecursion", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
           RowBox[{"MeshFunctions", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"#1", "&"}], "}"}]}], ",", 
           RowBox[{"MeshShading", "\[Rule]", "None"}], ",", 
           RowBox[{"MeshStyle", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"Method", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"PerformanceGoal", "\[RuleDelayed]", "$PerformanceGoal"}], 
           ",", 
           RowBox[{"PlotLabel", "\[Rule]", "None"}], ",", 
           RowBox[{"PlotPoints", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Full", ",", "Automatic"}], "}"}]}], ",", 
           RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotRangePadding", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"PlotRegion", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"PreserveImageOptions", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"Prolog", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"RegionFunction", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{"True", "&"}], ")"}]}], ",", 
           RowBox[{"RotateLabel", "\[Rule]", "True"}], ",", 
           RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"TicksStyle", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"WorkingPrecision", "\[Rule]", "MachinePrecision"}]}], 
          "}"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[Plot],
  Editable->False]], "Print",
 CellChangeTimes->{3.480155177750686*^9},
 CellTags->
  "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"]
}, Closed]],

Cell["\<\
Note also, that Hold\[Dash]Attributes don't prevent the parameter from being \
evaluated when processed further.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", "*", "5"}], "]"}]], "Input"],

Cell[TextData[{
 "With ",
 Cell[BoxData[
  ButtonBox["HoldAllComplete",
   BaseStyle->"RefGuideLink"]]],
 " not even ",
 StyleBox["Evaluate", "Input"],
 " has an effect."
}], "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Attributes", "[", "f", "]"}], "=", 
   RowBox[{"{", "HoldAllComplete", "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{"HoldForm", "[", 
   RowBox[{"x", "+", "1"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"3", "+", "5"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FullForm", "[", "%", "]"}]], "Input"],

Cell[TextData[{
 "We see that ",
 Cell[BoxData[
  ButtonBox["HoldForm",
   BaseStyle->"RefGuideLink"]]],
 " is similar to ",
 StyleBox["Hold", "Input"],
 " in that it keeps its parameters unevaluated. ",
 StyleBox["HoldForm", "Input"],
 ", however disappears in the display of the expression."
}], "Text"],

Cell[BoxData[
 RowBox[{"HoldForm", "[", 
  RowBox[{"3", "+", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  RowBox[{"3", "+", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", ">", "2"}], ",", 
    RowBox[{"x", "-", "2"}], ",", 
    FractionBox[
     RowBox[{"x", "+", "1"}], "2"], ",", "x"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", "+", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", "-", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{"f", "[", 
   RowBox[{"Hold", "[", 
    RowBox[{"3", "+", "5"}], "]"}], "]"}]}]], "Input"],

Cell[TextData[{
 "Note, that ",
 StyleBox["Hold", "Input"],
 " and ",
 StyleBox["HoldForm", "Input"],
 " can be removed inside expressions using ",
 Cell[BoxData[
  ButtonBox["ReleaseHold",
   BaseStyle->"RefGuideLink"]]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{"ReleaseHold", "[", 
  RowBox[{"a", "\[Equal]", "8"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ReleaseHold", "[", 
  RowBox[{"HoldForm", "[", 
   RowBox[{"3", "+", "5"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Execution of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[Dash]Programs"
}], "Section"],

Cell[TextData[{
 "The execution of ",
 StyleBox["Mathematica\[Dash]",
  FontSlant->"Italic"],
 "programs is driven exclusively by the mechanism of evaluation of \
expressions as described above in combination with \"pattern matching\". We \
define a \"program\" ",
 Cell[BoxData[
  FormBox["P", TraditionalForm]]],
 " ",
 "by giving a definition in the form"
}], "Text"],

Cell[BoxData[
 RowBox[{"lhs", ":=", "rhs"}]], "Input",
 Evaluatable->False],

Cell[TextData[{
 "where, in general, ",
 StyleBox["lhs", "Input"],
 " is a pattern and ",
 StyleBox["rhs", "Input"],
 " is an arbitrary expression. A program call to ",
 Cell[BoxData[
  FormBox["P", TraditionalForm]]],
 " happens, if, during the evaluation of some expression, there appears an \
expression that \"matches\" ",
 StyleBox["lhs", "Input"],
 " (with a certain substitution of pattern components), then the same \
substitution is carried out on ",
 StyleBox["rhs", "Input"],
 " and the resulting expression is evaluated. ",
 StyleBox["rhs", "Input"],
 " may eventually contain expressions such as ",
 StyleBox["Module[...]", "Input"],
 ", ",
 StyleBox["If[...]", "Input"],
 ", ",
 StyleBox["Switch[...]", "Input"],
 ", etc. However, the execution of these \"programming constructs\" also just \
follows the scheme of expression evaluation, only that most of these \
\"programming constructs\" use a special treatment of their parameters, since \
the parameters mostly contain entire program fragments."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Module", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HoldAll", ",", "Protected"}], "}"}]], "Output",
 CellChangeTimes->{3.480155801135612*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "If", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HoldRest", ",", "Protected"}], "}"}]], "Output",
 CellChangeTimes->{3.480155803252766*^9}]
}, Open  ]],

Cell[TextData[{
 "Hence, \"programming constructs\" are ",
 StyleBox["just expressions",
  FontSlant->"Italic"],
 ", whose evaluation simulates a certain \"program flow\". The behavior of a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[Dash]program is completely determined by the mechanism of evaluation."
}], "Text"],

Cell[CellGroupData[{

Cell["The Difference between = and :=", "Subsection"],

Cell[TextData[{
 "We have seen two different ways of assignment up to now: ",
 Cell[BoxData[
  ButtonBox["=",
   BaseStyle->"RefGuideLink"]]],
 " and ",
 Cell[BoxData[
  ButtonBox[":=",
   BaseStyle->"RefGuideLink"]]],
 ". In most cases, ",
 StyleBox["=", "Input"],
 " is used for simple assignment of values, whereas ",
 StyleBox[":=", "Input"],
 " is used in program definitions. However, this is not a law! The difference \
between the two is quite simple."
}], "Text"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"HoldForm", "[", 
   RowBox[{"lhs", "=", "rhs"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"HoldForm", "[", 
   RowBox[{"lhs", ":=", "rhs"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Attributes", "[", 
  RowBox[{"{", 
   RowBox[{"Set", ",", "SetDelayed"}], "}"}], "]"}]], "Input"],

Cell[TextData[{
 "This is all about the difference between the two: due to the attribute \
HoldFirst, ",
 StyleBox["=", "Input"],
 " evaluates the right\[Dash]hand side of the expression ",
 StyleBox["before the ",
  FontSlant->"Italic"],
 StyleBox["assignment",
  FontSlant->"Italic"],
 " is made, whereas ",
 StyleBox[":=", "Input"],
 " assigns the ",
 StyleBox["unevaluated form",
  FontSlant->"Italic"],
 " of the right\[Dash]hand side. Thus, the only difference is, that in ",
 StyleBox["lhs=rhs", "Input"],
 " the expression ",
 StyleBox["rhs", "Input"],
 " is evaluated at the time when the assignment is made, whereas in ",
 StyleBox["lhs:=rhs", "Input"],
 " the evaluation of ",
 StyleBox["rhs", "Input"],
 " is delayed to the time when ",
 StyleBox["lhs", "Input"],
 " is accessed.\nIn cases, where the right\[Dash]hand side does not evaluate \
in the first place, there is in fact no difference!"
}], "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", 
  RowBox[{"f", ",", "a", ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "=", "8"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "a"}]], "Input"],

Cell[BoxData["a"], "Input"],

Cell[BoxData[
 RowBox[{"a", ":=", "8"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "a"}]], "Input"],

Cell[BoxData["a"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"x", "+", "y"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", ",", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{"x", "+", "y"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", ",", "5"}], "]"}]], "Input"],

Cell[TextData[{
 "However, when defining a program, ",
 StyleBox["the intention usually ",
  FontSlant->"Italic"],
 "is that",
 StyleBox[" the program is executed when it is called",
  FontSlant->"Italic"],
 ", not ",
 StyleBox["when it is defined",
  FontSlant->"Italic"],
 ", therefore a program definition commonly uses ",
 StyleBox[":=", "Input"],
 " ."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a_", ",", "y_"}], "]"}], "=", 
   RowBox[{"a", "+", "y"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "f", "]"}]], "Input"],

Cell[TextData[{
 "BUT: Assume we have the function ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " given as"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"x", "-", "3"}]], 
   RowBox[{"Sin", "[", 
    RowBox[{"2", "x"}], "]"}]}]}]], "Input"],

Cell[TextData[{
 "We want to define a function, say ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]]],
 ", such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "[", "z", "]"}], ":=", 
    RowBox[{
     UnderoverscriptBox["\[Integral]", "0", "z"], 
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", "z_", "]"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "z"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "F"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", "3", "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "z_", "]"}], "=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"f", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "z"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "F"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", "3", "]"}], "//", "Timing"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Details of Evaluation", "Subsection"],

Cell[TextData[{
 "When evaluating an expression ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "[", 
    RowBox[{
     SubscriptBox["x", "1"], ",", "\[Ellipsis]", ",", 
     SubscriptBox["x", "n"]}], "]"}], TraditionalForm]]],
 " ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
 "first evaluates the head ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 ", "
}], "Text",
 CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "then evaluates the arguments ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["x", "n"]}], TraditionalForm]]],
 " depending on the attributes of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ","
}], "Text",
 CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "then applies transformations related to attributes such as ",
 StyleBox["Orderless", "Input"],
 ", ",
 StyleBox["Flat", "Input"],
 ", and ",
 StyleBox["Listable", "Input"],
 ","
}], "Text",
 CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["then applies user\[Dash]definitions,", "Text",
 CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
then applies built\[Dash]in definitions, and\
\>", "Text",
 CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["finally evaluates the resulting expression.", "Text",
 CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "When a ",
 StyleBox["definition",
  FontSlant->"Italic"],
 " is evaluated, as discussed before, the left\[Dash]hand side is kept \
unevaluated. However, in a definition"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{
    SubscriptBox["x", "1"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["x", "n"]}], "]"}], ":=", "rhs"}]], "Input",
 Evaluatable->False],

Cell[TextData[{
 "the arguments ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["x", "n"]}], TraditionalForm]]],
 " will be evaluated corresponding to the attributes of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " and possibly the arguments will be transformed according to attributes of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " such as ",
 StyleBox["Orderless", "Input"],
 ", ",
 StyleBox["Flat", "Input"],
 ", and ",
 StyleBox["Listable", "Input"],
 " in order to have definitions coherent with the evaluation strategy applied \
when later applying the definitions. \nThus, in general, attributes should be \
specified ",
 StyleBox["before",
  FontSlant->"Italic"],
 " the function definitions are given!\nWe go back to the example that we \
already had before:"
}], "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"8", ",", "2"}], "]"}], "=", "3"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "Orderless"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"8", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"8", ",", "2"}], "]"}], "=", "3"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"8", ",", "2"}], "]"}]], "Input"],

Cell[TextData[{
 "Thus, ",
 StyleBox["Orderless", "Input"],
 " is useful for a commutative operation, ",
 StyleBox["Flat", "Input"],
 " is useful for an associative operation, and ",
 StyleBox["Listable", "Input"],
 " is useful for operations to be applied component\[Dash]wise."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Currying", "Section"],

Cell[TextData[{
 StyleBox["Currying",
  FontSlant->"Italic"],
 " means that the head of an expression can itself be a composed expression, \
it need not necessarily be just a symbol."
}], "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"op_String", ",", "x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Switch", "[", 
    RowBox[{
    "op", ",", "\[IndentingNewLine]", "\"\<Plus\>\"", ",", "Plus", ",", 
     "\[IndentingNewLine]", "\"\<Times\>\"", ",", "Times", ",", 
     "\[IndentingNewLine]", "_", ",", "Hold"}], "]"}], "[", 
   RowBox[{"x", ",", "y"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"\"\<Plus\>\"", ",", "3", ",", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"\"\<Times\>\"", ",", "3", ",", "5"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"\"\<Minus\>\"", ",", "3", ",", "5"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Arrays and Lists", "Section"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "f"}], "]"}]], "Input"],

Cell[TextData[{
 "Arrays and lists in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are the same. "
}], "Text"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", ",", "b", ",", "c"}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"Range", "[", 
  RowBox[{"2", ",", "10"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Range", "[", "10", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Range", "[", 
  RowBox[{"1", ",", "10", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   SuperscriptBox["i", "2"], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "2", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   SuperscriptBox["i", "2"], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   SuperscriptBox["i", "2"], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "10", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"i", "/", "j"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "5", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Array", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", "10", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Input"],

Cell["\<\
Lists are again only expressions! There are (almost) no operations \
particularly for lists. Rather, there are operations for expressions \
(accessing parts, manipulating the structure, etc.), which can be used, as \
special cases, also for lists, see the subsequent sections.\
\>", "Text"],

Cell[CellGroupData[{

Cell["List Assignment", "Subsection"],

Cell["\<\
Assignment to symbols in a list can be done simultaneously, i.e.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Random", "[", "]"}], ",", 
    RowBox[{"{", "4", "}"}]}], "]"}]}]], "Input"],

Cell[BoxData["a"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{"c", ",", "d", ",", "a", ",", "b"}], "}"}]}]], "Input"],

Cell[BoxData["a"], "Input"],

Cell[BoxData["b"], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Manipulating Expressions", "Section"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Accessing Parts of Expressions", "Subsection"],

Cell[TextData[{
 "We can access the subexpressions by their position using ",
 Cell[BoxData[
  ButtonBox["Part",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"a", "\[Equal]", "b"}], ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"a", "\[Equal]", "b"}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "]"}], ",", "2"}], 
  "]"}]], "Input"],

Cell["\<\
As an abbreviation, we may use the (postfix) operator \"\[LeftDoubleBracket]  \
\[RightDoubleBracket]\" (enter via \[EscapeKey][[\[EscapeKey] and \
\[EscapeKey]]]\[EscapeKey], respectively) or in its long form \"[[\" and  \
\"]]\").\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "\[LeftDoubleBracket]", "3", 
  "\[RightDoubleBracket]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"a", "\[Equal]", "b"}], ")"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input"],

Cell["\<\
Negative positions are counted backwards from the last position of the \
expression.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "\[LeftDoubleBracket]", 
  RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]], "Input"],

Cell[TextData[{
 "Expressions may be ",
 StyleBox["nested",
  FontSlant->"Italic"],
 ", i.e. at every position in an expression there may be again an expression. \
Atomic expressions in this recursive structure are symbols, numbers, and \
strings."
}], "Text"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{"a", ",", 
    RowBox[{"g", "[", "23", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"p", "[", "\"\<K[x]\>\"", "]"}]}], "]"}]}], "]"}]}]], "Input"],

Cell["\<\
We can use multi\[Dash]indices to access parts in nested expressions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", 
  RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]], "Input"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", 
  RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]], "Input"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", 
  RowBox[{"3", ",", "2", ",", "1"}], "\[RightDoubleBracket]"}]], "Input"],

Cell["\<\
Furthermore, we can access several parts simultaneously. Note that the head \
of the original expression is put as the head of the resulting expression!\
\>", "Text"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2"}], "}"}], "\[RightDoubleBracket]"}]], "Input"],

Cell["\<\
Accessing parts of expressions can be tricky if Hold\[Dash]attributes \
maintain subexpressions in unevaluated form.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "HoldAll"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"2", "+", "2"}], ",", 
    RowBox[{"2", "+", "3"}]}], "]"}]}]], "Input"],

Cell["\<\
Suppose you want to further process the unevaluated subexpression contained \
in this expression.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{"expr", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}]], "Input"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", "2", 
  "\[RightDoubleBracket]"}]], "Input"],

Cell["\<\
As a workaround, one can use simultaneous access, which puts the original \
head as the head of the expression and, therefore, brings the \
Hold\[Dash]attributes into play.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"expr", "\[LeftDoubleBracket]", 
  RowBox[{"{", "2", "}"}], "\[RightDoubleBracket]"}]], "Input"],

Cell[TextData[{
 "As an alternative to ",
 StyleBox["Part", "Input"],
 " there is ",
 Cell[BoxData[
  ButtonBox["Extract",
   BaseStyle->"RefGuideLink"]]],
 ", which uses a slightly different syntax for specifying the position"
}], "Text"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", "1", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "As we see, the simultaneously extracted parts are always returned as a \
list, regardless of what the head of the original expression was (unlike ",
 StyleBox["Part", "Input"],
 "). Specifying a third argument, we can force an arbitrary head to be \
applied to the extracted expressions."
}], "Text"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", "2", "}"}], ",", "Hold"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "}"}], ",", "Hold"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Extract", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"{", "1", "}"}], ",", "f"}], "]"}], " "}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Accessing Consecutive Parts of Expressions", "Subsection"],

Cell["\<\
Of course, selecting chunks of expressions\[LongDash]such as e.g. the first \
10 parts or part 6 through 10\[LongDash]could be done by simultaneous access.\
\
\>", "Text"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox["i", "2"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "20"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6", ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[TextData[{
 "However, it is more convenient to use ",
 Cell[BoxData[
  ButtonBox["Take",
   BaseStyle->"RefGuideLink"]]],
 " for this purpose."
}], "Text"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"expr", ",", "10"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell["Of course \[Ellipsis]", "Text"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"-", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}], ",", "2"}], "}"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Accessing Parts via Non\[Dash]Integer Indices (Associative Arrays)\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "f", "]"}]], "Input"],

Cell[TextData[{
 "A datastructure that allows to access parts via non\[Dash]integer indices \
is often called ",
 StyleBox["associative array",
  FontSlant->"Italic"],
 ". In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", we would use standard expressions for representing associative arrays. \
Think of some object, say ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ", whose parts (values) you want to access through \"indices\" named \
\"winter\", \"spring\", \"summer\", and \"autumn\". We would define the \
individual values as"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "\"\<winter\>\"", "]"}], "=", "3"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "\"\<spring\>\"", "]"}], "=", "5"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "\"\<summer\>\"", "]"}], "=", "\"\<some value\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "\"\<autumn\>\"", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], ";"}]}], "Input"],

Cell["\<\
By just the normal way of expression evaluation, we can access the values by\
\>", "Text"],

Cell[BoxData[
 RowBox[{"f", "[", "\"\<spring\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", "\"\<autumn\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input"],

Cell[TextData[{
 "It should be clear, that ",
 StyleBox["any expression",
  FontSlant->"Italic"],
 " can serve as the index, we are not restricted to strings!"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Accessing Parts by Pattern Matching", "Subsection"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{"a", ",", 
    RowBox[{"g", "[", "23", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"\"\<K[x]\>\"", ",", "10"}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_g"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Integer"}], "]"}]], "Input"],

Cell[TextData[{
 "By default, ",
 Cell[BoxData[
  ButtonBox["Cases",
   BaseStyle->"RefGuideLink"]]],
 " only searches on the first level of a nested expression. The next call \
will search ",
 StyleBox["up to level",
  FontSlant->"Italic"],
 " 2."
}], "Text"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Integer", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Integer", ",", "Infinity"}], "]"}]], "Input"],

Cell["To search at level 3 only, use", "Text"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Integer", ",", 
   RowBox[{"{", "3", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_String"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_String", ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Symbol"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Symbol", ",", "Infinity"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_Symbol", ",", "Infinity", ",", 
   RowBox[{"Heads", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell["We can even immediately transform the extracted parts.", "Text"],

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", 
   RowBox[{
    RowBox[{"a_Integer", "?", "EvenQ"}], "\[Rule]", 
    RowBox[{"a", "/", "2"}]}], ",", "3"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Deleting Parts of Expressions", "Subsection"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{"a", ",", 
    RowBox[{"g", "[", "23", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"\"\<K[x]\>\"", ",", "10"}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Delete", "[", 
  RowBox[{"expr", ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Delete", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Delete", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"{", "3", "}"}]}], "}"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Deleting Consecutive Parts of Expressions", "Subsection"],

Cell["\<\
Of course, deleting chunks of expressions\[LongDash]such as e.g. the first 10 \
parts or part 6 through 10\[LongDash]could be done by simultaneous deletion.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox["i", "2"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "20"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Delete", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Delete", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6", ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[TextData[{
 "However, it is more convenient to use ",
 Cell[BoxData[
  ButtonBox["Drop",
   BaseStyle->"RefGuideLink"]]],
 " for this purpose."
}], "Text"],

Cell[BoxData[
 RowBox[{"Drop", "[", 
  RowBox[{"expr", ",", "10"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Drop", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Drop", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell["Of course \[Ellipsis]", "Text"],

Cell[BoxData[
 RowBox[{"Drop", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"-", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Drop", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Drop", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "3"}], ",", "2"}], "}"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Deleting Parts by Pattern Matching", "Subsection"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{"a", ",", 
    RowBox[{"g", "[", "23", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"\"\<K[x]\>\"", ",", "10"}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_g"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Integer"}], "]"}]], "Input"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  ButtonBox["DeleteCases",
   BaseStyle->"RefGuideLink"]]],
 " there are the same specialities like we saw them for ",
 StyleBox["Cases", "Input"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Integer", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Integer", ",", "Infinity"}], "]"}]], "Input"],

Cell["To delete at level 3 only, use", "Text"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Integer", ",", 
   RowBox[{"{", "3", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_String"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_String", ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Symbol"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Symbol", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "Infinity"}], "}"}], ",", 
   RowBox[{"Heads", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DeleteCases", "[", 
  RowBox[{"expr", ",", "_Symbol", ",", "Infinity", ",", 
   RowBox[{"Heads", "\[Rule]", "True"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Determining the Position of Elements in an Expression", "Subsection"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{"a", ",", 
    RowBox[{"g", "[", "23", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"\"\<K[x]\>\"", ",", "10"}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"expr", ",", "a"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"expr", ",", "_Integer"}], "]"}]], "Input"],

Cell[TextData[{
 "The structure returned by ",
 Cell[BoxData[
  ButtonBox["Position",
   BaseStyle->"RefGuideLink"]]],
 " specifying the position of elements in an expression corresponds exactly \
to the structure required for specifying positions in paramaters to ",
 StyleBox["Extract", "Input"],
 " and ",
 Cell[BoxData[
  ButtonBox["Delete",
   BaseStyle->"RefGuideLink"]]],
 ". Note, however, the position specification is slightly different in ",
 StyleBox["Part", "Input"],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Structural Manipulation of Expressions", "Subsection"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"Union", "[", 
   RowBox[{
    RowBox[{"{", "b", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "a"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Append", "[", 
  RowBox[{"expr", ",", "23"}], "]"}]], "Input"],

Cell[BoxData["expr"], "Input"],

Cell[BoxData[
 RowBox[{"AppendTo", "[", 
  RowBox[{"expr", ",", "d"}], "]"}]], "Input"],

Cell[BoxData["expr"], "Input"],

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", "expr", "}"}], ",", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<K[x]\>\"", ",", 
           RowBox[{"{", "10", "}"}]}], "}"}]}], "}"}], "}"}], ",", 
      RowBox[{"{", "23", "}"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Flatten", "[", "expr", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"expr", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"expr", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"expr", ",", "3"}], "]"}]], "Input"],

Cell[TextData[{
 "Flatten is designed to be used on lists, primarily. Flatten, in fact, \
removes \"List\" when it appears as the head of a subexpression. To remove \
heads different from \"List\", we must specify the head symbol as third \
parameter to ",
 Cell[BoxData[
  ButtonBox["Flatten",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
     RowBox[{"g", "[", "23", "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", "\"\<K[x]\>\""}], "]"}]}], "}"}], ",", 
   "1", ",", "g"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
     RowBox[{"g", "[", "23", "]"}], ",", 
     RowBox[{"p", "[", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", "\"\<K[x]\>\""}], "]"}]}], "}"}], ",", 
   "1", ",", "p"}], "]"}]], "Input"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["FlattenAt",
   BaseStyle->"RefGuideLink"]]],
 " can be used to specify the position where the list should be flattened."
}], "Text"],

Cell[BoxData["expr"], "Input"],

Cell[BoxData[
 RowBox[{"FlattenAt", "[", 
  RowBox[{"expr", ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FlattenAt", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FlattenAt", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Structuring an expression into parts of equal length can be done using ",
 Cell[BoxData[
  ButtonBox["Partition",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Partition", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Partition", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}], ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Partition", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "]"}], ",", "2"}], 
  "]"}]], "Input"],

Cell[TextData[{
 "We now just show some further structural manipulations available in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"Reverse", "[", "expr", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], "}"}], "]"}]], "Input"],

Cell[TextData[{
 "Of course, ",
 Cell[BoxData[
  ButtonBox["Transpose",
   BaseStyle->"RefGuideLink"]]],
 " is meant to compute the transposed matrix of a given matrix, but it is in \
some situations useful to see ",
 StyleBox["Transpose", "Input"],
 " as just a structural operation on nested list that \"collects all ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 "\[Dash]th elements\" of a nested list!"
}], "Text"],

Cell[BoxData[
 RowBox[{"Dot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inner", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inner", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "g"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Outer", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Outer", "[", 
  RowBox[{"List", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Equal", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"Equal", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}]], "Input"],

Cell[TextData[{
 "We urge to browse through the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Help (Section \"Lists and Matrices\") in order to find out even more \
possibilities available in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", and also to find out special capabilities of the functions mentioned in \
this chapter."
}], "Text"]
}, Closed]]
}, Closed]]
},
ScreenStyleEnvironment->"Presentation",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1280, 718},
WindowMargins->{{0, Automatic}, {1, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "wwindste",
    "Teaching", "ProgrammierenInMathematica", "Skriptum"}, 
  "3-Expressions.nb.ps", CharacterEncoding -> "iso8859-1"]},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"7.0 for Linux x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3480159505-1242375"->{
  Cell[12293, 519, 118, 2, 50, "Print",
   CellTags->"Info3480159505-1242375"],
  Cell[12414, 523, 932, 28, 74, "Print",
   CellTags->"Info3480159505-1242375"]},
 "Info3480160014-9080128"->{
  Cell[14424, 606, 118, 2, 50, "Print",
   CellTags->"Info3480160014-9080128"],
  Cell[14545, 610, 931, 28, 74, "Print",
   CellTags->"Info3480160014-9080128"]},
 "Info3480160073-5738855"->{
  Cell[16168, 675, 118, 2, 50, "Print",
   CellTags->"Info3480160073-5738855"],
  Cell[16289, 679, 930, 28, 74, "Print",
   CellTags->"Info3480160073-5738855"]},
 "Info3480160149-4147071"->{
  Cell[17536, 721, 118, 2, 50, "Print",
   CellTags->"Info3480160149-4147071"],
  Cell[17657, 725, 930, 28, 74, "Print",
   CellTags->"Info3480160149-4147071"]},
 "Info3480160305-1501528"->{
  Cell[19547, 799, 118, 2, 50, "Print",
   CellTags->"Info3480160305-1501528"],
  Cell[19668, 803, 966, 29, 74, "Print",
   CellTags->"Info3480160305-1501528"]},
 "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"->{
  Cell[26978, 1095, 803, 16, 89, "Print",
   CellTags->
    "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],
  Cell[27784, 1113, 1534, 38, 110, "Print",
   CellTags->
    "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],
  Cell[29472, 1160, 1814, 31, 89, "Print",
   CellTags->
    "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],
  Cell[31289, 1193, 5228, 108, 492, "Print",
   CellTags->
    "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3480159505-1242375", 78764, 2983},
 {"Info3480160014-9080128", 78955, 2988},
 {"Info3480160073-5738855", 79146, 2993},
 {"Info3480160149-4147071", 79337, 2998},
 {"Info3480160305-1501528", 79528, 3003},
 {"InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]", 79762, \
3008}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 93, 4, 103, "Title"],
Cell[CellGroupData[{
Cell[663, 28, 41, 0, 93, "Section"],
Cell[707, 30, 357, 15, 42, "Text"],
Cell[1067, 47, 118, 3, 70, "Input"],
Cell[1188, 52, 150, 5, 41, "Text"],
Cell[1341, 59, 114, 3, 70, "Input"],
Cell[1458, 64, 81, 2, 70, "Input"],
Cell[1542, 68, 86, 2, 70, "Input"],
Cell[1631, 72, 59, 1, 70, "Input"],
Cell[1693, 75, 61, 1, 70, "Input"],
Cell[1757, 78, 80, 2, 93, "Input"],
Cell[1840, 82, 57, 1, 70, "Input"],
Cell[1900, 85, 68, 1, 70, "Input"],
Cell[1971, 88, 179, 8, 41, "Text"],
Cell[2153, 98, 244, 8, 72, "Input"],
Cell[2400, 108, 128, 3, 41, "Text"],
Cell[2531, 113, 174, 5, 72, "Input"],
Cell[2708, 120, 430, 13, 70, "Text"],
Cell[3141, 135, 140, 4, 72, "Input"],
Cell[3284, 141, 68, 0, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3389, 146, 44, 0, 93, "Section"],
Cell[3436, 148, 532, 15, 109, "Text"],
Cell[CellGroupData[{
Cell[3993, 167, 229, 8, 70, "Input"],
Cell[4225, 177, 145, 4, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4407, 186, 309, 11, 70, "Input"],
Cell[4719, 199, 578, 19, 88, "Output"]
}, Open  ]],
Cell[5312, 221, 661, 24, 71, "Text"],
Cell[CellGroupData[{
Cell[5998, 249, 264, 9, 70, "Input"],
Cell[6265, 260, 994, 42, 68, "Output"]
}, Open  ]],
Cell[7274, 305, 1790, 58, 222, "Text"],
Cell[9067, 365, 67, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[9159, 371, 229, 8, 70, "Input"],
Cell[9391, 381, 145, 4, 68, "Output"]
}, Open  ]],
Cell[9551, 388, 121, 4, 70, "Input"],
Cell[CellGroupData[{
Cell[9697, 396, 229, 8, 70, "Input"],
Cell[9929, 406, 70, 1, 68, "Output"]
}, Open  ]],
Cell[10014, 410, 364, 13, 109, "Text"],
Cell[CellGroupData[{
Cell[10403, 427, 60, 1, 70, "Input"],
Cell[10466, 430, 69, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10572, 436, 77, 2, 70, "Input"],
Cell[10652, 440, 70, 1, 68, "Output"]
}, Open  ]],
Cell[10737, 444, 21, 0, 41, "Text"],
Cell[CellGroupData[{
Cell[10783, 448, 178, 4, 70, "Input"],
Cell[10964, 454, 272, 9, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11273, 468, 77, 2, 70, "Input"],
Cell[11353, 472, 120, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11522, 481, 29, 0, 93, "Section"],
Cell[11554, 483, 71, 0, 41, "Text"],
Cell[CellGroupData[{
Cell[11650, 487, 63, 1, 70, "Input"],
Cell[11716, 490, 87, 2, 68, "Output"]
}, Open  ]],
Cell[11818, 495, 146, 5, 41, "Text"],
Cell[11967, 502, 97, 2, 70, "Input"],
Cell[12067, 506, 154, 6, 42, "Text"],
Cell[CellGroupData[{
Cell[12246, 516, 44, 1, 70, "Input"],
Cell[12293, 519, 118, 2, 50, "Print",
 CellTags->"Info3480159505-1242375"],
Cell[12414, 523, 932, 28, 74, "Print",
 CellTags->"Info3480159505-1242375"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13383, 556, 135, 4, 70, "Input"],
Cell[13521, 562, 333, 14, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13891, 581, 101, 3, 70, "Input"],
Cell[13995, 586, 144, 4, 68, "Output"]
}, Open  ]],
Cell[14154, 593, 99, 2, 70, "Input"],
Cell[14256, 597, 96, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[14377, 603, 44, 1, 70, "Input"],
Cell[14424, 606, 118, 2, 50, "Print",
 CellTags->"Info3480160014-9080128"],
Cell[14545, 610, 931, 28, 74, "Print",
 CellTags->"Info3480160014-9080128"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15513, 643, 135, 4, 70, "Input"],
Cell[15651, 649, 333, 14, 68, "Output"]
}, Open  ]],
Cell[15999, 666, 97, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[16121, 672, 44, 1, 70, "Input"],
Cell[16168, 675, 118, 2, 50, "Print",
 CellTags->"Info3480160073-5738855"],
Cell[16289, 679, 930, 28, 74, "Print",
 CellTags->"Info3480160073-5738855"]
}, Open  ]],
Cell[17234, 710, 164, 3, 70, "Input"],
Cell[CellGroupData[{
Cell[17423, 717, 110, 2, 70, "Input"],
Cell[17536, 721, 118, 2, 50, "Print",
 CellTags->"Info3480160149-4147071"],
Cell[17657, 725, 930, 28, 74, "Print",
 CellTags->"Info3480160149-4147071"]
}, Open  ]],
Cell[18602, 756, 135, 4, 70, "Input"],
Cell[18740, 762, 101, 3, 70, "Input"],
Cell[18844, 767, 96, 2, 70, "Input"],
Cell[18943, 771, 44, 1, 70, "Input"],
Cell[18990, 774, 186, 6, 70, "Input"],
Cell[19179, 782, 196, 6, 42, "Text"],
Cell[19378, 790, 97, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[19500, 796, 44, 1, 70, "Input"],
Cell[19547, 799, 118, 2, 50, "Print",
 CellTags->"Info3480160305-1501528"],
Cell[19668, 803, 966, 29, 74, "Print",
 CellTags->"Info3480160305-1501528"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20671, 837, 77, 2, 70, "Input"],
Cell[20751, 841, 120, 3, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20908, 849, 77, 2, 70, "Input"],
Cell[20988, 853, 120, 3, 68, "Output"]
}, Open  ]],
Cell[21123, 859, 128, 5, 42, "Text"],
Cell[21254, 866, 92, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[21371, 872, 131, 4, 70, "Input"],
Cell[21505, 878, 130, 3, 68, "Output"]
}, Open  ]],
Cell[21650, 884, 158, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[21833, 894, 95, 2, 73, "Subsection"],
Cell[21931, 898, 154, 5, 42, "Text"],
Cell[22088, 905, 61, 1, 70, "Input"],
Cell[22152, 908, 185, 6, 42, "Text"],
Cell[22340, 916, 265, 6, 70, "Input"],
Cell[22608, 924, 164, 4, 70, "Input"],
Cell[CellGroupData[{
Cell[22797, 932, 142, 3, 70, "Input"],
Cell[22942, 937, 105, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23084, 943, 143, 3, 70, "Input"],
Cell[23230, 948, 96, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23363, 954, 116, 3, 70, "Input"],
Cell[23482, 959, 127, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23646, 965, 135, 2, 70, "Input"],
Cell[23784, 969, 100, 2, 68, "Output"]
}, Open  ]],
Cell[23899, 974, 330, 11, 71, "Text"],
Cell[CellGroupData[{
Cell[24254, 989, 109, 3, 70, "Input"],
Cell[24366, 994, 106, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24509, 1000, 258, 7, 70, "Input"],
Cell[24770, 1009, 235, 7, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25042, 1021, 130, 2, 70, "Input"],
Cell[25175, 1025, 122, 3, 68, "Output"]
}, Open  ]],
Cell[25312, 1031, 329, 10, 82, "Text"],
Cell[25644, 1043, 61, 1, 70, "Input"],
Cell[25708, 1046, 97, 2, 70, "Input"],
Cell[25808, 1050, 213, 5, 70, "Input"],
Cell[26024, 1057, 164, 4, 70, "Input"],
Cell[CellGroupData[{
Cell[26213, 1065, 77, 2, 70, "Input"],
Cell[26293, 1069, 105, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26435, 1075, 113, 3, 70, "Input"],
Cell[26551, 1080, 96, 1, 68, "Output"]
}, Open  ]],
Cell[26662, 1084, 170, 3, 70, "Input"],
Cell[CellGroupData[{
Cell[26857, 1091, 118, 2, 70, "Input"],
Cell[26978, 1095, 803, 16, 89, "Print",
 CellTags->
  "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],
Cell[27784, 1113, 1534, 38, 110, "Print",
 CellTags->"InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"]
}, Closed]],
Cell[CellGroupData[{
Cell[29355, 1156, 114, 2, 64, "Input"],
Cell[29472, 1160, 1814, 31, 89, "Print",
 CellTags->
  "InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"],
Cell[31289, 1193, 5228, 108, 492, "Print",
 CellTags->"InfoIntegerPart[AbsoluteTime[]]-RandomInteger[{1000000, 9999999}]"]
}, Closed]],
Cell[36532, 1304, 136, 3, 35, "Text"],
Cell[36671, 1309, 77, 2, 70, "Input"],
Cell[36751, 1313, 182, 8, 42, "Text"],
Cell[36936, 1323, 61, 1, 70, "Input"],
Cell[37000, 1326, 143, 4, 70, "Input"],
Cell[37146, 1332, 138, 4, 70, "Input"],
Cell[37287, 1338, 113, 3, 70, "Input"],
Cell[37403, 1343, 61, 1, 70, "Input"],
Cell[37467, 1346, 305, 10, 70, "Text"],
Cell[37775, 1358, 84, 2, 70, "Input"],
Cell[37862, 1362, 80, 2, 70, "Input"],
Cell[37945, 1366, 61, 1, 70, "Input"],
Cell[38009, 1369, 251, 8, 93, "Input"],
Cell[38263, 1379, 77, 2, 70, "Input"],
Cell[38343, 1383, 77, 2, 70, "Input"],
Cell[38423, 1387, 134, 4, 70, "Input"],
Cell[38560, 1393, 239, 10, 42, "Text"],
Cell[38802, 1405, 94, 2, 70, "Input"],
Cell[38899, 1409, 123, 3, 70, "Input"],
Cell[39025, 1414, 61, 1, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39135, 1421, 116, 5, 93, "Section"],
Cell[39254, 1428, 370, 11, 69, "Text"],
Cell[39627, 1441, 75, 2, 70, "Input",
 Evaluatable->False],
Cell[39705, 1445, 1026, 26, 185, "Text"],
Cell[CellGroupData[{
Cell[40756, 1475, 68, 1, 70, "Input"],
Cell[40827, 1478, 129, 3, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40993, 1486, 64, 1, 70, "Input"],
Cell[41060, 1489, 130, 3, 68, "Output"]
}, Open  ]],
Cell[41205, 1495, 328, 8, 69, "Text"],
Cell[CellGroupData[{
Cell[41558, 1507, 53, 0, 73, "Subsection"],
Cell[41614, 1509, 472, 15, 70, "Text"],
Cell[42089, 1526, 124, 3, 70, "Input"],
Cell[42216, 1531, 125, 3, 70, "Input"],
Cell[42344, 1536, 121, 3, 70, "Input"],
Cell[42468, 1541, 919, 26, 169, "Text"],
Cell[43390, 1569, 94, 2, 70, "Input"],
Cell[43487, 1573, 67, 2, 70, "Input"],
Cell[43557, 1577, 44, 1, 70, "Input"],
Cell[43604, 1580, 27, 0, 70, "Input"],
Cell[43634, 1582, 50, 1, 70, "Input"],
Cell[43687, 1585, 44, 1, 70, "Input"],
Cell[43734, 1588, 27, 0, 70, "Input"],
Cell[43764, 1590, 127, 4, 70, "Input"],
Cell[43894, 1596, 44, 1, 70, "Input"],
Cell[43941, 1599, 77, 2, 70, "Input"],
Cell[44021, 1603, 147, 5, 70, "Input"],
Cell[44171, 1610, 44, 1, 70, "Input"],
Cell[44218, 1613, 77, 2, 70, "Input"],
Cell[44298, 1617, 369, 13, 70, "Text"],
Cell[44670, 1632, 147, 5, 70, "Input"],
Cell[44820, 1639, 44, 1, 70, "Input"],
Cell[44867, 1642, 58, 1, 70, "Input"],
Cell[44928, 1645, 128, 5, 41, "Text"],
Cell[45059, 1652, 212, 7, 70, "Input"],
Cell[45274, 1661, 399, 15, 70, "Text"],
Cell[45676, 1678, 230, 7, 70, "Input"],
Cell[45909, 1687, 44, 1, 70, "Input"],
Cell[45956, 1690, 83, 2, 70, "Input"],
Cell[46042, 1694, 253, 8, 70, "Input"],
Cell[46298, 1704, 44, 1, 70, "Input"],
Cell[46345, 1707, 83, 2, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46465, 1714, 47, 0, 73, "Subsection"],
Cell[46515, 1716, 290, 11, 41, "Text"],
Cell[46808, 1729, 170, 6, 41, "Text"],
Cell[46981, 1737, 352, 12, 41, "Text"],
Cell[47336, 1751, 264, 9, 42, "Text"],
Cell[47603, 1762, 109, 1, 41, "Text"],
Cell[47715, 1765, 125, 3, 41, "Text"],
Cell[47843, 1770, 116, 1, 41, "Text"],
Cell[47962, 1773, 199, 6, 41, "Text"],
Cell[48164, 1781, 193, 6, 70, "Input",
 Evaluatable->False],
Cell[48360, 1789, 866, 26, 178, "Text"],
Cell[49229, 1817, 61, 1, 70, "Input"],
Cell[49293, 1820, 121, 4, 70, "Input"],
Cell[49417, 1826, 97, 2, 70, "Input"],
Cell[49517, 1830, 77, 2, 70, "Input"],
Cell[49597, 1834, 44, 1, 70, "Input"],
Cell[49644, 1837, 58, 1, 70, "Input"],
Cell[49705, 1840, 121, 4, 70, "Input"],
Cell[49829, 1846, 44, 1, 70, "Input"],
Cell[49876, 1849, 77, 2, 70, "Input"],
Cell[49956, 1853, 291, 8, 70, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50296, 1867, 27, 0, 93, "Section"],
Cell[50326, 1869, 195, 5, 70, "Text"],
Cell[50524, 1876, 61, 1, 70, "Input"],
Cell[50588, 1879, 403, 10, 70, "Input"],
Cell[50994, 1891, 98, 2, 70, "Input"],
Cell[51095, 1895, 99, 2, 70, "Input"],
Cell[51197, 1899, 99, 2, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[51333, 1906, 35, 0, 65, "Section"],
Cell[51371, 1908, 101, 2, 49, "Input"],
Cell[51475, 1912, 120, 5, 27, "Text"],
Cell[51598, 1919, 82, 2, 49, "Input"],
Cell[51683, 1923, 82, 2, 49, "Input"],
Cell[51768, 1927, 59, 1, 49, "Input"],
Cell[51830, 1930, 92, 2, 49, "Input"],
Cell[51925, 1934, 166, 5, 49, "Input"],
Cell[52094, 1941, 156, 5, 49, "Input"],
Cell[52253, 1948, 176, 5, 49, "Input"],
Cell[52432, 1955, 225, 7, 49, "Input"],
Cell[52660, 1964, 106, 3, 49, "Input"],
Cell[52769, 1969, 118, 3, 49, "Input"],
Cell[52890, 1974, 300, 5, 47, "Text"],
Cell[CellGroupData[{
Cell[53215, 1983, 37, 0, 46, "Subsection"],
Cell[53255, 1985, 88, 2, 70, "Text"],
Cell[53346, 1989, 227, 7, 70, "Input"],
Cell[53576, 1998, 27, 0, 70, "Input"],
Cell[53606, 2000, 183, 5, 70, "Input"],
Cell[53792, 2007, 27, 0, 70, "Input"],
Cell[53822, 2009, 27, 0, 70, "Input"],
Cell[53852, 2011, 101, 2, 70, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[54002, 2019, 43, 0, 65, "Section"],
Cell[54048, 2021, 124, 3, 49, "Input"],
Cell[CellGroupData[{
Cell[54197, 2028, 52, 0, 46, "Subsection"],
Cell[54252, 2030, 162, 6, 70, "Text"],
Cell[54417, 2038, 139, 4, 70, "Input"],
Cell[54559, 2044, 111, 3, 70, "Input"],
Cell[54673, 2049, 111, 3, 70, "Input"],
Cell[54787, 2054, 167, 5, 70, "Input"],
Cell[54957, 2061, 256, 5, 70, "Text"],
Cell[55216, 2068, 153, 4, 70, "Input"],
Cell[55372, 2074, 131, 4, 70, "Input"],
Cell[55506, 2080, 108, 3, 70, "Text"],
Cell[55617, 2085, 168, 4, 70, "Input"],
Cell[55788, 2091, 260, 7, 70, "Text"],
Cell[56051, 2100, 271, 8, 70, "Input"],
Cell[56325, 2110, 93, 2, 70, "Text"],
Cell[56421, 2114, 119, 2, 70, "Input"],
Cell[56543, 2118, 119, 2, 70, "Input"],
Cell[56665, 2122, 129, 2, 70, "Input"],
Cell[56797, 2126, 176, 3, 70, "Text"],
Cell[56976, 2131, 143, 3, 70, "Input"],
Cell[57122, 2136, 140, 3, 70, "Text"],
Cell[57265, 2141, 61, 1, 70, "Input"],
Cell[57329, 2144, 95, 2, 70, "Input"],
Cell[57427, 2148, 154, 5, 70, "Input"],
Cell[57584, 2155, 121, 3, 70, "Text"],
Cell[57708, 2160, 83, 2, 70, "Input"],
Cell[57794, 2164, 99, 2, 70, "Input"],
Cell[57896, 2168, 99, 2, 70, "Input"],
Cell[57998, 2172, 196, 4, 70, "Text"],
Cell[58197, 2178, 119, 2, 70, "Input"],
Cell[58319, 2182, 239, 8, 70, "Text"],
Cell[58561, 2192, 110, 3, 70, "Input"],
Cell[58674, 2197, 110, 3, 70, "Input"],
Cell[58787, 2202, 187, 6, 70, "Input"],
Cell[58977, 2210, 318, 6, 70, "Text"],
Cell[59298, 2218, 123, 3, 70, "Input"],
Cell[59424, 2223, 200, 6, 70, "Input"],
Cell[59627, 2231, 140, 4, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[59804, 2240, 64, 0, 30, "Subsection"],
Cell[59871, 2242, 181, 4, 70, "Text"],
Cell[60055, 2248, 196, 6, 70, "Input"],
Cell[60254, 2256, 195, 6, 70, "Input"],
Cell[60452, 2264, 205, 6, 70, "Input"],
Cell[60660, 2272, 160, 6, 70, "Text"],
Cell[60823, 2280, 84, 2, 70, "Input"],
Cell[60910, 2284, 133, 4, 70, "Input"],
Cell[61046, 2290, 143, 4, 70, "Input"],
Cell[61192, 2296, 37, 0, 70, "Text"],
Cell[61232, 2298, 102, 3, 70, "Input"],
Cell[61337, 2303, 174, 6, 70, "Input"],
Cell[61514, 2311, 184, 6, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[61735, 2322, 96, 2, 30, "Subsection"],
Cell[61834, 2326, 61, 1, 70, "Input"],
Cell[61898, 2329, 562, 15, 70, "Text"],
Cell[62463, 2346, 526, 17, 70, "Input"],
Cell[62992, 2365, 100, 2, 70, "Text"],
Cell[63095, 2369, 67, 1, 70, "Input"],
Cell[63165, 2372, 67, 1, 70, "Input"],
Cell[63235, 2375, 44, 1, 70, "Input"],
Cell[63282, 2378, 171, 5, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[63490, 2388, 57, 0, 30, "Subsection"],
Cell[63550, 2390, 304, 10, 70, "Input"],
Cell[63857, 2402, 85, 2, 70, "Input"],
Cell[63945, 2406, 91, 2, 70, "Input"],
Cell[64039, 2410, 260, 10, 70, "Text"],
Cell[64302, 2422, 101, 2, 70, "Input"],
Cell[64406, 2426, 108, 2, 70, "Input"],
Cell[64517, 2430, 46, 0, 70, "Text"],
Cell[64566, 2432, 125, 3, 70, "Input"],
Cell[64694, 2437, 90, 2, 70, "Input"],
Cell[64787, 2441, 100, 2, 70, "Input"],
Cell[64890, 2445, 90, 2, 70, "Input"],
Cell[64983, 2449, 107, 2, 70, "Input"],
Cell[65093, 2453, 154, 3, 70, "Input"],
Cell[65250, 2458, 70, 0, 70, "Text"],
Cell[65323, 2460, 186, 5, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[65546, 2470, 51, 0, 30, "Subsection"],
Cell[65600, 2472, 304, 10, 70, "Input"],
Cell[65907, 2484, 85, 2, 70, "Input"],
Cell[65995, 2488, 134, 4, 70, "Input"],
Cell[66132, 2494, 186, 6, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[66355, 2505, 63, 0, 30, "Subsection"],
Cell[66421, 2507, 180, 3, 70, "Text"],
Cell[66604, 2512, 196, 6, 70, "Input"],
Cell[66803, 2520, 223, 7, 70, "Input"],
Cell[67029, 2529, 233, 7, 70, "Input"],
Cell[67265, 2538, 160, 6, 70, "Text"],
Cell[67428, 2546, 84, 2, 70, "Input"],
Cell[67515, 2550, 133, 4, 70, "Input"],
Cell[67651, 2556, 143, 4, 70, "Input"],
Cell[67797, 2562, 37, 0, 70, "Text"],
Cell[67837, 2564, 102, 3, 70, "Input"],
Cell[67942, 2569, 174, 6, 70, "Input"],
Cell[68119, 2577, 184, 6, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[68340, 2588, 56, 0, 30, "Subsection"],
Cell[68399, 2590, 304, 10, 70, "Input"],
Cell[68706, 2602, 91, 2, 70, "Input"],
Cell[68800, 2606, 97, 2, 70, "Input"],
Cell[68900, 2610, 204, 8, 70, "Text"],
Cell[69107, 2620, 107, 2, 70, "Input"],
Cell[69217, 2624, 114, 2, 70, "Input"],
Cell[69334, 2628, 46, 0, 70, "Text"],
Cell[69383, 2630, 131, 3, 70, "Input"],
Cell[69517, 2635, 96, 2, 70, "Input"],
Cell[69616, 2639, 106, 2, 70, "Input"],
Cell[69725, 2643, 96, 2, 70, "Input"],
Cell[69824, 2647, 209, 5, 70, "Input"],
Cell[70036, 2654, 160, 3, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[70233, 2662, 75, 0, 30, "Subsection"],
Cell[70311, 2664, 304, 10, 70, "Input"],
Cell[70618, 2676, 87, 2, 70, "Input"],
Cell[70708, 2680, 94, 2, 70, "Input"],
Cell[70805, 2684, 497, 15, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[71339, 2704, 60, 0, 30, "Subsection"],
Cell[71402, 2706, 184, 6, 70, "Input"],
Cell[71589, 2714, 86, 2, 70, "Input"],
Cell[71678, 2718, 30, 0, 70, "Input"],
Cell[71711, 2720, 87, 2, 70, "Input"],
Cell[71801, 2724, 30, 0, 70, "Input"],
Cell[71834, 2726, 444, 14, 70, "Input"],
Cell[72281, 2742, 63, 1, 70, "Input"],
Cell[72347, 2745, 86, 2, 70, "Input"],
Cell[72436, 2749, 86, 2, 70, "Input"],
Cell[72525, 2753, 86, 2, 70, "Input"],
Cell[72614, 2757, 344, 9, 70, "Text"],
Cell[72961, 2768, 348, 11, 70, "Input"],
Cell[73312, 2781, 348, 11, 70, "Input"],
Cell[73663, 2794, 176, 5, 70, "Text"],
Cell[73842, 2801, 30, 0, 70, "Input"],
Cell[73875, 2803, 88, 2, 70, "Input"],
Cell[73966, 2807, 137, 4, 70, "Input"],
Cell[74106, 2813, 216, 7, 70, "Input"],
Cell[74325, 2822, 181, 6, 70, "Text"],
Cell[74509, 2830, 197, 6, 70, "Input"],
Cell[74709, 2838, 197, 6, 70, "Input"],
Cell[74909, 2846, 172, 5, 70, "Input"],
Cell[75084, 2853, 155, 5, 70, "Text"],
Cell[75242, 2860, 63, 1, 70, "Input"],
Cell[75308, 2863, 211, 7, 70, "Input"],
Cell[75522, 2872, 425, 12, 70, "Text"],
Cell[75950, 2886, 197, 6, 70, "Input"],
Cell[76150, 2894, 209, 6, 70, "Input"],
Cell[76362, 2902, 219, 6, 70, "Input"],
Cell[76584, 2910, 209, 6, 70, "Input"],
Cell[76796, 2918, 212, 6, 70, "Input"],
Cell[77011, 2926, 199, 6, 70, "Input"],
Cell[77213, 2934, 237, 7, 70, "Input"],
Cell[77453, 2943, 357, 10, 70, "Text"]
}, Closed]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
