(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     90573,       3379]
NotebookOptionsPosition[     76500,       2950]
NotebookOutlinePosition[     77381,       2980]
CellTagsIndexPosition[     77305,       2975]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Functions As Expressions", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Expressions Representing Functions"
}], "Section"],

Cell[TextData[{
 "Some ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands expect functions being passed as parameters, e.g."
}], "Text"],

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"{", 
   RowBox[{"5", ",", "2", ",", "1", ",", "4", ",", "3", ",", "4"}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "2", ",", "1", ",", "4", ",", "3", ",", "4"}], "}"}], 
   ",", "Greater"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", "a", "}"}], "}"}], ",", 
    RowBox[{"{", "b", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "c", "}"}], ",", "d"}], "}"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Deeper", "[", 
   RowBox[{"l1_", ",", "l2_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Depth", "[", "l1", "]"}], "\[GreaterEqual]", 
   RowBox[{"Depth", "[", "l2", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "a", "}"}], "}"}], ",", 
     RowBox[{"{", "b", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "c", "}"}], ",", "d"}], "}"}]}], "}"}], ",", "Deeper"}], 
  "]"}]], "Input"],

Cell[TextData[{
 "In these examples, functions were passed as parameters by passing their \
name. Compare to C/C++, where the function name is identified with a pointer \
to the function. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", however, there is no such concept like pointers. Any symbol can be passed \
as a parameter to a program and if we consider it to be a function name then \
we just ",
 StyleBox["apply",
  FontSlant->"Italic"],
 " it to arguments."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Compare", "[", 
    RowBox[{"x_", ",", "y_", ",", "comp_"}], "]"}], "/;", 
   RowBox[{"comp", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ":=", "x"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Compare", "[", 
   RowBox[{"x_", ",", "y_", ",", "comp_"}], "]"}], ":=", "y"}]], "Input"],

Cell[BoxData[
 RowBox[{"Compare", "[", 
  RowBox[{"3", ",", "10", ",", "Less"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Compare", "[", 
  RowBox[{"3", ",", "10", ",", "Greater"}], "]"}]], "Input"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " offers functions ",
 StyleBox["as expressions",
  FontSlant->"Italic"],
 " without defining them under a certain name. "
}], "Text"],

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}]}]], "Input"],

Cell[TextData[{
 "Expressions with head ",
 Cell[BoxData[
  ButtonBox["Function",
   BaseStyle->"RefGuideLink"]]],
 " are called ",
 StyleBox["pure functions",
  FontSlant->"Italic"],
 ". They can be ",
 StyleBox["applied",
  FontSlant->"Italic"],
 " to arguments."
}], "Text"],

Cell[BoxData[
 RowBox[{"f", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], "[", "3", "]"}]], "Input"],

Cell["\<\
This is again currying! 
In short form, we can write # as a placeholder for the function variable. \
Don't forget the & at the end of the expression marking it to be a function.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    SuperscriptBox["#", "2"], ")"}], "&"}], "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     SuperscriptBox["#", "2"], ")"}], "&"}], "[", "3", "]"}], "//", 
  "FullForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   SuperscriptBox["#", "2"], ")"}], "//", "FullForm"}]], "Input"],

Cell["\<\
Similarly, multivariate functions can be expressed as follows:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], "]"}], "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input"],

Cell[TextData[{
 "In short form, we can write ",
 Cell[BoxData[
  FormBox[
   RowBox[{"#", "i"}], TraditionalForm]]],
 " for the ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 "\[Dash]th variable and mark the resulting expression as a function using \
&."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["#1", "2"], "+", 
      SuperscriptBox["#2", "2"]}]], "&"}], ")"}], "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["#1", "2"], "+", 
      SuperscriptBox["#2", "2"]}]], "&"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input"],

Cell["In the example above:", "Text"],

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", "#1", "]"}], ">", 
     RowBox[{"Abs", "[", "#2", "]"}]}], "&"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "a", "}"}], "}"}], ",", 
     RowBox[{"{", "b", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "c", "}"}], ",", "d"}], "}"}]}], "}"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Depth", "[", "#1", "]"}], "\[GreaterEqual]", 
     RowBox[{"Depth", "[", "#2", "]"}]}], "&"}]}], "]"}]], "Input"],

Cell["\<\
Of course, functions are just expressions like all other expressions and they \
can occur even as the return value in a program.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearFunction", "[", 
   RowBox[{"k_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "+", "d"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"LinearFunction", "[", 
  RowBox[{"3", ",", "7"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LinearFunction", "[", 
   RowBox[{"3", ",", "7"}], "]"}], "[", "1", "]"}]], "Input"],

Cell[TextData[{
 StyleBox["Function", "Input"],
 " is a scoping construct (like ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"RefGuideLink"]]],
 ", ",
 Cell[BoxData[
  ButtonBox["Sum",
   BaseStyle->"RefGuideLink"]]],
 ", ",
 Cell[BoxData[
  ButtonBox["Integrate",
   BaseStyle->"RefGuideLink"]]],
 ", ",
 Cell[BoxData[
  ButtonBox["Module",
   BaseStyle->"RefGuideLink"]]],
 ", ",
 Cell[BoxData[
  ButtonBox["Block",
   BaseStyle->"RefGuideLink"]]],
 ") that treats the function variable as a locally bound symbol. Thus, in \
certain situations, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " renames the bound variable in order to avoid naming conflicts. Moreover, "
}], "Text"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "Function", "]"}]], "Input"],

Cell["\<\
when manipulating Function\[Dash]expressions, we need to be aware of the Hold\
\[Dash]attribute!\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", "f", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Applying Functions to Expressions", "Section"],

Cell[CellGroupData[{

Cell["Standard Function Application", "Subsection"],

Cell["\<\
Functions can be applied to expressions in various forms, the easiest being \
to apply the function to the appropriate number of arguments, i.e.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], "]"}], "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Componentwise Application of a Unary Function", "Subsection"],

Cell["\<\
However, we often need to apply functions to expressions in some special way, \
e.g. componentwise\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", 
     SuperscriptBox["x", "2"]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   SuperscriptBox["x", "2"], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "+", "4"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Moreover, we can specify at which level the function should be applied.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "+", "4"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "3", "}"}], ",", "4"}], "}"}], ",", "2"}], "]"}]], "Input"],

Cell["Try to understand what happens in the previous example!", "Text"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "+", "4"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "3", "}"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Application at Specified Positions", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"expr", "=", 
   RowBox[{"f", "[", 
    RowBox[{"a", ",", 
     RowBox[{"g", "[", "23", "]"}], ",", 
     RowBox[{"h", "[", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       RowBox[{"p", "[", 
        RowBox[{"\"\<K[x]\>\"", ",", "10"}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"_Integer", "?", "EvenQ"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MapAt", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "/", "2"}], "&"}], ",", "expr", ",", 
   RowBox[{"Position", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"_Integer", "?", "EvenQ"}]}], "]"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Componentwise Application Taking into Account the Position", \
"Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input"],

Cell["\<\
Suppose we want to put an index indication the position to every part of an \
expression. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["#1", 
     RowBox[{"#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
    "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input"],

Cell["Alternative 1:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PutSubscript", "[", 
   RowBox[{"e_", ",", 
    RowBox[{"{", "s_", "}"}]}], "]"}], ":=", 
  SubscriptBox["e", "s"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PutSubscript", "[", 
   RowBox[{"e_", ",", "s_"}], "]"}], ":=", 
  SubscriptBox["e", 
   RowBox[{
   "s", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}]], "Input"],

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{"PutSubscript", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Alternative 2: This variant is even more general. It allows to specify an \
alphabet from which the respective indices are taken.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"IndexAlphabet", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<I\>\"", ",", "\"\<II\>\"", ",", "\"\<III\>\""}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PutSubscript", "[", 
     RowBox[{"#1", ",", 
      RowBox[{"{", 
       RowBox[{"Extract", "[", 
        RowBox[{"IndexAlphabet", ",", "#2"}], "]"}], "}"}]}], "]"}], "&"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Alternative 3: we can use ",
 Cell[BoxData[
  ButtonBox["MapThread",
   BaseStyle->"RefGuideLink"]]],
 ", see next section."
}], "Text"],

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PutSubscript", "[", 
     RowBox[{"#1", ",", 
      RowBox[{"{", "#2", "}"}]}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "IndexAlphabet"}], 
    "}"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compontwise Application of Binary Function", "Subsection"],

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"Equal", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
     RowBox[{"Range", "[", "3", "]"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "The same can always be established using ",
 Cell[BoxData[
  ButtonBox["Inner",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Inner", "[", 
  RowBox[{"Equal", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"Range", "[", "3", "]"}], ",", "List"}], "]"}]], "Input"],

Cell["Compare:", "Text"],

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"Equal", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"Range", "[", "3", "]"}]}], "]"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Function Application to Argument\[Dash]Expression\
\>", "Subsection"],

Cell[TextData[{
 "A different way of function application to an expression is to ",
 StyleBox["feed the arguments of the expression as parameters to the function",
  FontSlant->"Italic"],
 ". This can be done using ",
 Cell[BoxData[
  ButtonBox["Apply",
   BaseStyle->"RefGuideLink"]]],
 ".",
 StyleBox[" ",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Often, the expression is a list, but it not necessarily be a list!\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"f", ",", 
   RowBox[{"g", "[", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Table", ",", 
   RowBox[{"f", "[", 
    RowBox[{
     SuperscriptBox["i", "2"], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[TextData[{
 StyleBox["Apply[f,expr]", "Input"],
 " effectively just substitutes the head of ",
 StyleBox["expr", "Input"],
 " by ",
 StyleBox["f", "Input"],
 " and then evaluates the resulting expression."
}], "Text"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#1", "-", 
     SuperscriptBox["#2", "2"]}], "&"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "3"}], "]"}]}], "]"}]], "Input"],

Cell["More examples:", "Text"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", 
   RowBox[{"Map", "[", 
    RowBox[{"f", ",", 
     RowBox[{"Range", "[", "5", "]"}]}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["#", "2"], "&"}], ",", 
     RowBox[{"Range", "[", "5", "]"}]}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], "5"], 
  SuperscriptBox["i", "2"]}]], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Iteration Through Repeated Function Application", "Section"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " offers some commands that allow to replace ",
 StyleBox["iteration",
  FontSlant->"Italic"],
 " by certain ",
 StyleBox["variants of function application",
  FontSlant->"Italic"],
 ". ",
 Cell[BoxData[
  ButtonBox["Map",
   BaseStyle->"RefGuideLink"]]],
 ", ",
 Cell[BoxData[
  ButtonBox["MapThread",
   BaseStyle->"RefGuideLink"]]],
 ", and ",
 Cell[BoxData[
  ButtonBox["MapIndexed",
   BaseStyle->"RefGuideLink"]]],
 " were first examples. Similar to ",
 StyleBox["Map", "Input"],
 ", just without returning the result, is ",
 Cell[BoxData[
  ButtonBox["Scan",
   BaseStyle->"RefGuideLink"]]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Scan", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"#", "=", "0"}], ")"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 StyleBox["Map", "Input"],
 " would have the same effect, but it would produce a return value. Of \
course, we can suppress the return value using \";\" or, in a program, we can \
simply ",
 StyleBox["ignore",
  FontSlant->"Italic"],
 " the return value, but I prefer ",
 StyleBox["Scan", "Input"],
 " for these purposes."
}], "Text"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", ",", "b", ",", "c"}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input"],

Cell[TextData[{
 "Then there is ",
 Cell[BoxData[
  ButtonBox["Nest",
   BaseStyle->"RefGuideLink"]]],
 ", performs a fixed number of iterations starting with a given value."
}], "Text"],

Cell[BoxData[
 RowBox[{"Nest", "[", 
  RowBox[{"f", ",", "x", ",", "4"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Nest", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "+", "2"}], "&"}], ",", "20", ",", "4"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"NestList", "[", 
  RowBox[{"f", ",", "x", ",", "4"}], "]"}]], "Input"],

Cell[TextData[{
 "Similar to ",
 StyleBox["Nest", "Input"],
 ", but without a fixed number of repetitions, is ",
 Cell[BoxData[
  ButtonBox["FixedPoint",
   BaseStyle->"RefGuideLink"]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"FixedPoint", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{"Cos", "[", "#1", "]"}], "]"}], "&"}], ",", "0.5", ",", 
   RowBox[{"SameTest", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"#1", "-", "#2"}], "]"}], "<", "0.0001"}], "&"}], ")"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FixedPointList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{"Cos", "[", "#1", "]"}], "]"}], "&"}], ",", "0.5", ",", 
   RowBox[{"SameTest", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"#1", "-", "#2"}], "]"}], "<", "0.0001"}], "&"}], ")"}]}]}], 
  "]"}]], "Input"],

Cell["Further variations:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fold", "[", 
  RowBox[{"f", ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "1"}], "]"}], ",", "2"}], "]"}], ",", "3"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.418546195537193*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FoldList", "[", 
  RowBox[{"f", ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "1"}], "]"}], ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "1"}], "]"}], ",", "2"}], "]"}], ",", "3"}], 
    "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.418546278172725*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ComposeList", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f", ",", "g", ",", "h"}], "}"}], ",", "x"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"NestWhileList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "#"}], "&"}], ",", "1", ",", 
   RowBox[{
    RowBox[{"#", "<", "150"}], "&"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Exercise: FoldRight", "Subsection"],

Cell[TextData[{
 "Implement a function ",
 StyleBox["FoldRight", "Input"],
 ", which, like the  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[Dash]Function ",
 Cell[BoxData[
  ButtonBox["Fold",
   BaseStyle->"RefGuideLink"]]],
 ", folds a function ",
 StyleBox["f", "Input"],
 " ",
 StyleBox["from right",
  FontSlant->"Italic"],
 " over a list."
}], "Text"],

Cell[BoxData[
 RowBox[{"Fold", "[", 
  RowBox[{"f", ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input"],

Cell["results in", "Text"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "a"}], "]"}], ",", "b"}], "]"}], ",", "c"}], 
  "]"}]], "DisplayFormula"],

Cell[BoxData[
 RowBox[{"FoldRight", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "x"}], "]"}]], "Input"],

Cell["should result in:", "Text"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"a", ",", 
   RowBox[{"f", "[", 
    RowBox[{"b", ",", 
     RowBox[{"f", "[", 
      RowBox[{"c", ",", "x"}], "]"}]}], "]"}]}], "]"}]], "DisplayFormula"],

Cell[TextData[{
 "Solution: see ",
 ButtonBox["separate notebook",
  BaseStyle->"Hyperlink",
  ButtonData:>{"FoldRight-Solution.nb", None}],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise: Random Walk", "Subsection"],

Cell[TextData[{
 "Let's consider once more the program ",
 StyleBox["RandomWalk", "Input"],
 " from the very beginning. We started with a \"procedural implementation\" \
containing to nested ",
 Cell[BoxData[
  ButtonBox["Do",
   BaseStyle->"RefGuideLink"]]],
 "\[Dash]loops. The inner loop represented 10 random movements, the outer \
loop repeated the random walk a fixed number of times in order to approximate \
the probability for the random walk to stop at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"7", ",", "3"}], "}"}], TraditionalForm]]],
 ".\nWrite a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " program that approximates the probability for the random walk using 10 \
steps to stop at some position ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " (input parameter). Implement all \"loops\" using some variants of repeated \
function application."
}], "Text"],

Cell[TextData[{
 "Solution: see ",
 ButtonBox["separate notebook",
  BaseStyle->"Hyperlink",
  ButtonData:>{"RandomWalk-Solution.nb", None}],
 "."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pure Functions vs. Named Functions", "Section"],

Cell[TextData[{
 "The main difference between pure functions and named functions that are \
introduced by a function definition is that pure functions lack the \
possibility of ",
 StyleBox["pattern matching",
  FontSlant->"Italic"],
 " in the parameters. Thus, often a powerful combination is to introduce \
named functions using the full power of pattern matching and then apply these \
functions appropriately using ",
 StyleBox["Map", "Input"],
 ", ",
 StyleBox["Apply", "Input"],
 ", and the like, as already demonstrated above. Note, however, that \
attributes can also be assigned to pure functions. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Unevaluated", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", 
    RowBox[{"10", "!"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Unevaluated", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"3", "+", "5"}], ",", 
    RowBox[{"10", "!"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.41854664579569*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Head", ",", 
   RowBox[{"Unevaluated", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "+", "5"}], ",", 
      RowBox[{"10", "!"}]}], "}"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Integer", ",", "Integer"}], "}"}]], "Output",
 CellChangeTimes->{3.418546657439991*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Head", "]"}]], "Input",
 CellChangeTimes->{{3.41854675469878*^9, 3.418546760672297*^9}}],

Cell[BoxData[
 RowBox[{"{", "Protected", "}"}]], "Output",
 CellChangeTimes->{3.418546761116335*^9, 3.450501031271029*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Head", "[", 
      RowBox[{"Unevaluated", "[", "x", "]"}], "]"}], ",", 
     RowBox[{"{", "HoldFirst", "}"}]}], "]"}], ",", 
   RowBox[{"Unevaluated", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "+", "5"}], ",", 
      RowBox[{"10", "!"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.418546961837612*^9, {3.450501077526079*^9, 3.450501083022235*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Plus", ",", "Factorial"}], "}"}]], "Output",
 CellChangeTimes->{3.41854692908877*^9, 3.418546963532793*^9, 
  3.450501083825664*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selecting Parts of Expressions by Property", "Section"],

Cell[TextData[{
 "We already know ",
 StyleBox["Cases", "Input"],
 " for selecting parts of an expression that match a certain pattern. \
Alternatively, we can select parts that fulfill a given test."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"f", "[", 
   RowBox[{"a", ",", 
    RowBox[{"g", "[", "23", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"\"\<K[x]\>\"", ",", "10"}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"a", ",", 
   RowBox[{"g", "[", "23", "]"}], ",", 
   RowBox[{"h", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     RowBox[{"p", "[", 
      RowBox[{"\<\"K[x]\"\>", ",", "10"}], "]"}]}], "]"}]}], "]"}]], "Output",\

 CellChangeTimes->{3.418547205480681*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{"expr", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Length", "[", "#", "]"}], "\[GreaterEqual]", "2"}], "&"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"h", "[", 
   RowBox[{
    FractionBox["1", "2"], ",", 
    RowBox[{"p", "[", 
     RowBox[{"\<\"K[x]\"\>", ",", "10"}], "]"}]}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.418547208598088*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"expr", ",", "_g"}], "]"}]], "Input",
 CellChangeTimes->{{3.418547366112135*^9, 3.41854739059793*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"g", "[", "23", "]"}], "}"}]], "Output",
 CellChangeTimes->{{3.418547377381042*^9, 3.418547391393857*^9}}]
}, Open  ]],

Cell[TextData[{
 "Note, that, unlike ",
 StyleBox["Cases", "Input"],
 ", the head of the original expression is conserved in the result. ",
 StyleBox["Cases", "Input"],
 " always returns a list."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transformation Rules", "Section"],

Cell[CellGroupData[{

Cell["Transformation Rules as an Alternative for Functions", "Subsection"],

Cell[TextData[{
 "Function application is very much related to substitution, i.e. the ",
 StyleBox["function application",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", "a", "]"}], TraditionalForm]]],
 " is computed by ",
 StyleBox["substituting",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " for the function variable in ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ". If ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " is introduced through a definition in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " then this substitution happens in the pattern matching process of \
expression evaluation. If ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " is a ",
 StyleBox["pure function",
  FontSlant->"Italic"],
 " of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", "body"}], "]"}], TraditionalForm]]],
 ",",
 " then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", "a", "]"}], TraditionalForm]]],
 " happens to substitute ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " in body and then evaluates the resulting expression.",
 " "
}], "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", "a", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], "[", "a", "]"}]], "Input"],

Cell[BoxData[
 SuperscriptBox["a", "2"]], "Output",
 CellChangeTimes->{3.418547523113278*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, when working with functions it is often convenient to just work on \
the expression defining the function. Instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", "body"}], "]"}], TraditionalForm]]],
 " we only consider 'body'. In these situations we need to use ",
 StyleBox["the operation of substitution explicitly",
  FontSlant->"Italic"],
 " instead of function application."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReplaceAll", "[", 
  RowBox[{
   SuperscriptBox["x", "2"], ",", 
   RowBox[{"x", "\[Rule]", "a"}]}], "]"}]], "Input"],

Cell[BoxData[
 SuperscriptBox["a", "2"]], "Output",
 CellChangeTimes->{3.418547564967556*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.418547683055805*^9, 3.418547686366685*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"x", "\[Rule]", "a"}], "]"}]], "Input",
 CellChangeTimes->{{3.418547708940662*^9, 3.418547715418935*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Rule", "[", 
    RowBox[{"x", ",", "4"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{3.418547716416673*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Rule", "]"}]], "Input",
 CellChangeTimes->{{3.418547730107205*^9, 3.4185477345712*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Protected", ",", "SequenceHold"}], "}"}]], "Output",
 CellChangeTimes->{3.418547735185898*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "ReplaceAll", "]"}]], "Input",
 CellChangeTimes->{{3.418547776271311*^9, 3.418547785881697*^9}}],

Cell[BoxData[
 RowBox[{"{", "Protected", "}"}]], "Output",
 CellChangeTimes->{3.418547786560418*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   SuperscriptBox["x", "2"], "]"}], "/.", 
  RowBox[{"x", "\[Rule]", "a", " "}]}]], "Input",
 CellChangeTimes->{
  3.418547892482455*^9, {3.418547967697915*^9, 3.418547968716388*^9}, {
   3.418548093021868*^9, 3.418548099659669*^9}, {3.418548305833729*^9, 
   3.418548306769437*^9}, 3.418548344609278*^9}],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  SuperscriptBox["x", "2"], "]"}]], "Output",
 CellChangeTimes->{
  3.418547648215397*^9, 3.418547822156107*^9, 3.418547853344338*^9, 
   3.418547920916041*^9, {3.418547970439995*^9, 3.418547981384991*^9}, 
   3.418548102805649*^9, 3.41854830746133*^9, 3.418548345462679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"Hold", "[", 
   SuperscriptBox["x", "2"], "]"}]}]], "Input",
 CellChangeTimes->{{3.418548607908047*^9, 3.418548616806605*^9}}],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  SuperscriptBox["x", "2"], "]"}]], "Output",
 CellChangeTimes->{3.418548617648104*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["#", "3"], "&"}], ",", "expr"}], "]"}]], "Input",
 CellChangeTimes->{{3.418548630573066*^9, 3.418548649505621*^9}, {
  3.418548841462532*^9, 3.41854884630343*^9}}],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["#1", "3"], "&"}], ")"}], "[", 
   SuperscriptBox["x", "2"], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.418548650255899*^9, 3.418548848968348*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sqrt", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.418548953184284*^9, 3.418548954684584*^9}}],

Cell[BoxData[
 SqrtBox["3"]], "Output",
 CellChangeTimes->{3.418548955415542*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"x", "=."}]], "Input",
 CellChangeTimes->{{3.418548765950846*^9, 3.418548769217022*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "/.", 
  RowBox[{
   SuperscriptBox["x", "2"], "\[Rule]", 
   SuperscriptBox["x", "6"]}]}]], "Input",
 CellChangeTimes->{{3.418548723238212*^9, 3.418548750691121*^9}, {
  3.418548877544531*^9, 3.418548878094087*^9}}],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  SuperscriptBox["x", "6"], "]"}]], "Output",
 CellChangeTimes->{{3.418548752925147*^9, 3.418548771945527*^9}, 
   3.418548880102601*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Hold", "]"}]], "Input",
 CellChangeTimes->{{3.418548558506112*^9, 3.418548562112431*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HoldAll", ",", "Protected"}], "}"}]], "Output",
 CellChangeTimes->{3.418548562763579*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", "=", "3"}], "}"}], ",", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", "=", "x"}], "}"}], ",", "expr"}], "]"}]}], "]"}], "//", 
  "Trace"}]], "Input",
 CellChangeTimes->{{3.418548987108849*^9, 3.418549073124746*^9}, {
   3.41854913245535*^9, 3.41854913284988*^9}, {3.418549164936939*^9, 
   3.41854916824536*^9}, 3.418549258830939*^9, {3.418549328294253*^9, 
   3.418549365355753*^9}, {3.418549432433076*^9, 3.418549434940033*^9}, {
   3.418549737644218*^9, 3.418549784306074*^9}, {3.418549825192082*^9, 
   3.418549829541386*^9}, {3.418549925030701*^9, 3.418549957187585*^9}, {
   3.418550047325484*^9, 3.418550048878953*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", "=", "3"}], "}"}], ",", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", "=", "x"}], "}"}], ",", "expr"}], "]"}]}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", "=", "3"}], "}"}], ",", "expr"}], "]"}],
    HoldForm], ",", 
   TagBox["expr",
    HoldForm], ",", 
   TagBox[
    RowBox[{"Hold", "[", 
     SuperscriptBox["x", "2"], "]"}],
    HoldForm]}], "}"}]], "Output",
 CellChangeTimes->{
  3.418549786397897*^9, 3.418549830083832*^9, {3.41854995164133*^9, 
   3.418549958766596*^9}, 3.418550049705949*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.41854986349502*^9, 3.418549869163474*^9}}],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  SuperscriptBox["3", "2"], "]"}]], "Output",
 CellChangeTimes->{3.4185498749841*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "With", "]"}]], "Input",
 CellChangeTimes->{{3.418549181453005*^9, 3.418549186724916*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HoldAll", ",", "Protected"}], "}"}]], "Output",
 CellChangeTimes->{3.418549187170031*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReleaseHold", "[", "%31", "]"}]], "Input",
 CellChangeTimes->{{3.418548393516929*^9, 3.418548401914848*^9}}],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.418548433577449*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["x"], "Input",
 CellChangeTimes->{3.418547928053039*^9}],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{3.418547928366614*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.418547841238168*^9, 3.418547843333208*^9}, {
  3.418547905713335*^9, 3.418547906136645*^9}, {3.41854797618739*^9, 
  3.418547976858146*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Expressions Representing Transformation Rules"
}], "Subsection"],

Cell[TextData[{
 "In fact, when working with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expressions it is often convenient to perform certain transformations. It \
is sometimes \"easier\" to apply a transformation than to apply a certain \
function performing the transformation. The expression ",
 StyleBox["lhs\[Rule]rhs", "Input"],
 " is called a ",
 StyleBox["transformation rule",
  FontSlant->"Italic"],
 " and there are several operations (like ",
 Cell[BoxData[
  ButtonBox["ReplaceAll",
   BaseStyle->"RefGuideLink"]]],
 " above) for applying transformation rules to expressions. \nNote that \
pattern matching is available also in the application of transformation \
rules, i.e. when applying a transformation rule, the left\[Dash]hand side of \
the rule may contain pattern expressions and when an expression ",
 StyleBox["matches",
  FontSlant->"Italic"],
 " the left\[Dash]hand side of the transformation rule it is going to be \
substituted by the respective instance of the right\[Dash]hand side."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"3", 
   SuperscriptBox["x", "2"]}], "/.", 
  RowBox[{
   SuperscriptBox["x", 
    RowBox[{"n_", "?", "EvenQ"}]], "\[Rule]", 
   SuperscriptBox["z", 
    RowBox[{"n", "/", "2"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3", " ", "z"}]], "Output",
 CellChangeTimes->{3.41855038780586*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "2"]}], "/.", 
   RowBox[{
    SuperscriptBox["x", 
     RowBox[{"n_", "?", "EvenQ"}]], "\[Rule]", 
    SuperscriptBox["z", 
     RowBox[{"n", "/", "2"}]]}]}], "//", "Trace"}]], "Input"],

Cell[TextData[{
 "Now imagine you want to represent each even power ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "n"], TraditionalForm]]],
 " as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["x", 
      RowBox[{"n", "/", "2"}]], ")"}], "2"], TraditionalForm]]],
 ". Similar to above, we would use"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"3", 
   SuperscriptBox["x", "4"]}], "/.", 
  RowBox[{
   SuperscriptBox["x", 
    RowBox[{"n_", "?", "EvenQ"}]], "\[Rule]", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["x", 
      RowBox[{"n", "/", "2"}]], ")"}], "2"]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3", " ", 
  SuperscriptBox["x", "4"]}]], "Output",
 CellChangeTimes->{3.418550408350976*^9}]
}, Open  ]],

Cell["What happens here?", "Text"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"x", "\[Rule]", "a"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"Hold", "[", 
   RowBox[{
    RowBox[{"3", 
     SuperscriptBox["x", "4"]}], "/.", 
    RowBox[{
     SuperscriptBox["x", 
      RowBox[{"n_", "?", "EvenQ"}]], "\[Rule]", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["x", 
        RowBox[{"n", "/", "2"}]], ")"}], "2"]}]}], "]"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Rule", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Protected", ",", "SequenceHold"}], "}"}]], "Output",
 CellChangeTimes->{3.418550433245845*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Attributes", "[", "ReplaceAll", "]"}]], "Input"],

Cell[TextData[{
 "Now everything is clear! ",
 StyleBox["ReplaceAll", "Input"],
 " evaluates the transformation rule before the transformation is actually \
applied and the transformation rule ",
 StyleBox["lhs\[Rule]rhs", "Input"],
 " evaluates both ",
 StyleBox["lhs", "Input"],
 " and ",
 StyleBox["rhs", "Input"],
 ", thus"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", 
   RowBox[{"n_", "?", "EvenQ"}]], "\[Rule]", 
  SuperscriptBox[
   RowBox[{"(", 
    SuperscriptBox["x", 
     RowBox[{"n", "/", "2"}]], ")"}], "2"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", 
   RowBox[{"n_", "?", "EvenQ"}]], "\[Rule]", 
  SuperscriptBox["x", "n"]}]], "Output",
 CellChangeTimes->{3.418550486850753*^9}]
}, Open  ]],

Cell["\<\
This rule, of course, is the identical transformation, therefore it has no \
effect. What we need here is a rule that does not evaluate its \
right\[Dash]hand side!\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "RuleDelayed", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"x", "\[RuleDelayed]", "a"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"RuleDelayed", "[", 
    RowBox[{"x", ",", "a"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{3.418550544877575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", 
   RowBox[{"n_", "?", "EvenQ"}]], "\[RuleDelayed]", 
  SuperscriptBox[
   RowBox[{"(", 
    SuperscriptBox["x", 
     RowBox[{"n", "/", "2"}]], ")"}], "2"]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", 
   RowBox[{"n_", "?", "EvenQ"}]], "\[RuleDelayed]", 
  SuperscriptBox[
   RowBox[{"(", 
    SuperscriptBox["x", 
     RowBox[{"n", "/", "2"}]], ")"}], "2"]}]], "Output",
 CellChangeTimes->{3.418550578287676*^9}]
}, Open  ]],

Cell["Fine, this is what we wanted.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"3", 
   SuperscriptBox["x", "4"]}], "/.", 
  RowBox[{
   SuperscriptBox["x", 
    RowBox[{"n_", "?", "EvenQ"}]], "\[RuleDelayed]", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["x", 
      RowBox[{"n", "/", "2"}]], ")"}], "2"]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3", " ", 
  SuperscriptBox["x", "4"]}]], "Output",
 CellChangeTimes->{3.418550615635127*^9}]
}, Open  ]],

Cell[TextData[{
 "Why does it still not work? Think about this ",
 StyleBox["before",
  FontSlant->"Italic"],
 " you proceed with the subsequent statements."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "/.", 
   RowBox[{
    SuperscriptBox["x", 
     RowBox[{"n_", "?", "EvenQ"}]], "\[RuleDelayed]", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["x", 
       RowBox[{"n", "/", "2"}]], ")"}], "2"]}]}], "//", "Trace"}]], "Input"],

Cell[TextData[{
 "The rule is applied correctly and it results in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["x", "2"], ")"}], "2"]}], TraditionalForm]]],
 ", which is ",
 StyleBox["then",
  FontSlant->"Italic"],
 " evaluated further by the standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " evaluation loop resulting in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "]"}], "/.", 
  RowBox[{
   SuperscriptBox["x", 
    RowBox[{"n_", "?", "EvenQ"}]], "\[RuleDelayed]", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["x", 
      RowBox[{"n", "/", "2"}]], ")"}], "2"]}]}]], "Input"],

Cell[TextData[{
 "Note, however, that transformation rules apply inside ",
 StyleBox["Hold", "Input"],
 ", so this gives a possibility to modify expressions whose standard \
evaluation is suppressed by ",
 StyleBox["Hold", "Input"],
 ". Note also, that substituting 4/2 by 2 in the expression above might be \
tricky, since a transformation rule "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", "/", "2"}], "\[Rule]", "2"}]], "Input"],

Cell[TextData[{
 "will always evaluate the left\[Dash]hand side and there is no variant of a \
transformation rule that keeps its left\[Dash]hand side unevaluated. For this \
purpose one uses ",
 Cell[BoxData[
  ButtonBox["HoldPattern",
   BaseStyle->"RefGuideLink"]]],
 " as a wrapper for the left\[Dash]hand side of the rule."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["x", 
       RowBox[{"4", "/", "2"}]], ")"}], "2"]}], "]"}], "/.", 
  RowBox[{
   RowBox[{"HoldPattern", "[", 
    RowBox[{"4", "/", "2"}], "]"}], "\[Rule]", "2"}]}]], "Input"],

Cell[TextData[{
 "An expression ",
 StyleBox["HoldPattern[patt]", "Input"],
 " keeps 'patt' unevaluated and it behaves like 'patt' for pattern matching."
}], "Text"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "HoldPattern", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "RuleDelayed", "]"}]], "Input",
 CellChangeTimes->{{3.418550768197953*^9, 3.418550776016048*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HoldRest", ",", "Protected", ",", "SequenceHold"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.418550776806548*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["How to Apply a Transformation Rule to an Expression", "Subsection"],

Cell[TextData[{
 "There are various possibilities how to actually apply transformation rules \
to an expression. ",
 StyleBox["Replace[expr,rule]", "Input"],
 " applies ",
 StyleBox["rule", "Input"],
 " to ",
 StyleBox["expr", "Input"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Replace", "[", 
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], ",", 
   RowBox[{
    RowBox[{"c_", " ", 
     SuperscriptBox["b_", "4"]}], "\[Rule]", 
    SuperscriptBox["c", "b"]}]}], "]"}]], "Input"],

Cell[TextData[{
 "However, ",
 Cell[BoxData[
  ButtonBox["Replace",
   BaseStyle->"RefGuideLink"]]],
 " does not apply to subexpressions, i.e. the transformation is only applied \
to the entire expression as a whole but not to parts of it."
}], "Text"],

Cell[BoxData[
 RowBox[{"Replace", "[", 
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], ",", " ", 
   RowBox[{
    SuperscriptBox["b_", "4"], "\[Rule]", "b"}]}], "]"}]], "Input"],

Cell[TextData[{
 "If we want to apply rules to all possible subparts of an expression, then \
we should use ",
 StyleBox["ReplaceAll", "Input"],
 " or its short infix form ",
 Cell[BoxData[
  ButtonBox["/.",
   BaseStyle->"RefGuideLink"]]],
 " ."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", 
   SuperscriptBox["x", "4"]}], "/.", " ", 
  RowBox[{
   SuperscriptBox["b_", "4"], "\[Rule]", "b"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"5", 
    SuperscriptBox["y", "12"]}], "+", 
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}]}], "/.", " ", 
  RowBox[{
   RowBox[{"c_", " ", 
    SuperscriptBox["b_", 
     RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", "1"}], ")"}], 
    SuperscriptBox["b", 
     RowBox[{"n", "/", "2"}]]}]}]}]], "Input"],

Cell[TextData[{
 "If a subexpression is transformed once then ",
 StyleBox["ReplaceAll", "Input"],
 " immediately proceeds with the ",
 StyleBox["next subexpression",
  FontSlant->"Italic"],
 ", even if further transformations could be done on the original position. \
This is why, in the example above, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "6"], TraditionalForm]]],
 " are not transformed further. ",
 Cell[BoxData[
  ButtonBox["ReplaceRepeated",
   BaseStyle->"RefGuideLink"]]],
 " (short infix ",
 Cell[BoxData[
  ButtonBox["//.",
   BaseStyle->"RefGuideLink"]]],
 ") applies transformations repeatedly to all subexpressions until no further \
transformation is possible."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"5", 
    SuperscriptBox["y", "12"]}], "+", 
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}]}], "//.", " ", 
  RowBox[{
   RowBox[{"c_", " ", 
    SuperscriptBox["b_", 
     RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", "1"}], ")"}], 
    SuperscriptBox["b", 
     RowBox[{"n", "/", "2"}]]}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["How to Apply Rules Simultaneously", "Subsection"],

Cell[TextData[{
 "When applying transformation rules to an expression, we can use a ",
 StyleBox["structured list of transformation rules",
  FontSlant->"Italic"],
 " in order to apply more than one rule. The list\[Dash]structure of the \
transformation rules influences the way how rules are applied."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"5", 
    SuperscriptBox["y", "12"]}], "+", 
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c_", " ", 
      SuperscriptBox["b_", 
       RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", "1"}], ")"}], 
      SuperscriptBox["b", 
       RowBox[{"n", "/", "2"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c_", " ", 
      SuperscriptBox["b_", "n_"]}], "\[RuleDelayed]", " ", 
     SuperscriptBox["b", 
      RowBox[{"n", "+", "1"}]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"5", 
    SuperscriptBox["y", "12"]}], "+", 
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c_", " ", 
      SuperscriptBox["b_", "n_"]}], "\[Rule]", " ", 
     SuperscriptBox["b", 
      RowBox[{"n", "+", "1"}]]}], ",", 
    RowBox[{
     RowBox[{"c_", " ", 
      SuperscriptBox["b_", 
       RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", "1"}], ")"}], 
      SuperscriptBox["b", 
       RowBox[{"n", "/", "2"}]]}]}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "When applying a ",
 StyleBox["list",
  FontSlant->"Italic"],
 " of transformation rules ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["r", "1"], ",", "\[Ellipsis]", ",", 
     SubscriptBox["r", "n"]}], "}"}], TraditionalForm]]],
 " to an expression then, at each applicable position (depending on whether \
being used with ",
 StyleBox["Replace", "Input"],
 ", ",
 StyleBox["ReplaceAll", "Input"],
 ", or ",
 StyleBox["ReplaceRepeated", "Input"],
 "), ",
 StyleBox["the first matching rule only",
  FontSlant->"Italic"],
 " is applied.",
 StyleBox[" ",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"5", 
    SuperscriptBox["y", "12"]}], "+", 
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c_", " ", 
       SuperscriptBox["b_", "n_"]}], "\[Rule]", " ", 
      SuperscriptBox["b", 
       RowBox[{"n", "+", "1"}]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c_", " ", 
       SuperscriptBox["b_", 
        RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", "+", "1"}], ")"}], 
       SuperscriptBox["b", 
        RowBox[{"n", "/", "2"}]]}]}], "}"}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "When applying a ",
 StyleBox["list of lists",
  FontSlant->"Italic"],
 " of transformation rules ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["list", "1"], ",", "\[Ellipsis]", ",", 
     SubscriptBox["list", "n"]}], "}"}], TraditionalForm]]],
 " to an expression then the result is a list of expressions having at \
position ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " the result of applying ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["list", "i"], TraditionalForm]]],
 " to the expression. There is also a variant of ",
 StyleBox["Replace", "Input"],
 ", which not only applies the first matching rule in a list, but which \
returns a list containing all possible replacements."
}], "Text"],

Cell[BoxData[
 RowBox[{"ReplaceList", "[", 
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"c_", " ", 
       SuperscriptBox["b_", "n_"]}], "\[Rule]", " ", 
      SuperscriptBox["b", 
       RowBox[{"n", "+", "1"}]]}], ",", 
     RowBox[{
      RowBox[{"c_", " ", 
       SuperscriptBox["b_", 
        RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", "+", "1"}], ")"}], 
       SuperscriptBox["b", 
        RowBox[{"n", "/", "2"}]]}]}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ReplaceList", "[", 
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"c_", " ", 
       SuperscriptBox["b_", "n_"]}], "\[Rule]", " ", 
      SuperscriptBox["b", 
       RowBox[{"n", "+", "1"}]]}], ",", 
     RowBox[{
      RowBox[{"c_", " ", 
       SuperscriptBox["b_", 
        RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", "+", "1"}], ")"}], 
       SuperscriptBox["b", 
        RowBox[{"n", "/", "2"}]]}]}]}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Note the difference to using a list of lists of transformation rules.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Replace", "[", 
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["z", "3"]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c_", " ", 
        SuperscriptBox["b_", "n_"]}], "\[Rule]", " ", 
       SuperscriptBox["b", 
        RowBox[{"n", "+", "1"}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c_", " ", 
        SuperscriptBox["b_", 
         RowBox[{"n_", "?", "EvenQ"}]]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c", "+", "1"}], ")"}], 
        SuperscriptBox["b", 
         RowBox[{"n", "/", "2"}]]}]}], "}"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Many ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions return their result in form of transformation rules, in \
particular ",
 Cell[BoxData[
  ButtonBox["Solve",
   BaseStyle->"RefGuideLink"]]],
 " and related functions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\"Programming\" by Application of Transformation Rules", "Subsection"],

Cell[TextData[{
 "Repeated application of transformations can be seen as a means for \
programming. As an example, we can setup some rules for differentiation of an \
expression as transformation rules. In order to keep things simple, we fix ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " as the variable for differentiation. Then we write ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "'"}], TraditionalForm]]],
 " for differentiation of expression ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " w.r.t. ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "3"], 
      RowBox[{"Sin", "[", "x", "]"}]}], "+", 
     RowBox[{"2", 
      RowBox[{"Log", "[", 
       RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}], "'"}], "/.", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"f_", "+", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
   RowBox[{
    RowBox[{"f", "'"}], "+", 
    RowBox[{"g", "'"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "3"], 
      RowBox[{"Sin", "[", "x", "]"}]}], "+", 
     RowBox[{"2", 
      RowBox[{"Log", "[", 
       RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}], "'"}], "//.", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"f_", "+", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
   RowBox[{
    RowBox[{"f", "'"}], "+", 
    RowBox[{"g", "'"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "3"], 
      RowBox[{"Sin", "[", "x", "]"}]}], "+", 
     RowBox[{"2", 
      RowBox[{"Log", "[", 
       RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}], "'"}], "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f_", "+", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"f", "'"}], "+", 
      RowBox[{"g", "'"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["x", "n_"], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"n", " ", 
      SuperscriptBox["x", 
       RowBox[{"n", "-", "1"}]]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c_", " ", "f_"}], ")"}], "'"}], "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"c", ",", "x"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"c", " ", 
      RowBox[{"f", "'"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f_", "*", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "g"}], "+", 
      RowBox[{
       RowBox[{"g", "'"}], "f"}]}]}]}], "}"}]}]], "Input"],

Cell["\<\
The order of the rules in the list matters: Multiplication with a constant \
must occur before the general product rule.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "3"], 
      RowBox[{"Sin", "[", "x", "]"}]}], "+", 
     RowBox[{"2", 
      RowBox[{"Log", "[", 
       RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}], "'"}], "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f_", "+", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"f", "'"}], "+", 
      RowBox[{"g", "'"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["x", "n_"], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"n", " ", 
      SuperscriptBox["x", 
       RowBox[{"n", "-", "1"}]]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f_", "*", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "g"}], "+", 
      RowBox[{
       RowBox[{"g", "'"}], "f"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c_", " ", "f_"}], ")"}], "'"}], "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"c", ",", "x"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"c", " ", 
      RowBox[{"f", "'"}]}]}]}], "}"}]}]], "Input"],

Cell["Find out what happened exactly in this (wrong) computation.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "3"], 
      RowBox[{"Sin", "[", "x", "]"}]}], "+", 
     RowBox[{"2", 
      RowBox[{"Log", "[", 
       RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}], "'"}], "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f_", "+", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"f", "'"}], "+", 
      RowBox[{"g", "'"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["x", "n_"], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"n", " ", 
      SuperscriptBox["x", 
       RowBox[{"n", "-", "1"}]]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c_", " ", "f_"}], ")"}], "'"}], "/;", 
      RowBox[{"FreeQ", "[", 
       RowBox[{"c", ",", "x"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"c", " ", 
      RowBox[{"f", "'"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f_", "*", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "g"}], "+", 
      RowBox[{
       RowBox[{"g", "'"}], "f"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", "x"], ")"}], "'"}], "\[RuleDelayed]", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"1", "/", "x"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"Cos", "[", "x", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "x", "]"}]}]}]}], "}"}]}]], "Input"],

Cell["The chain rule is a little tricky:", "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"Log", "[", 
    RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[Prime]",
   MultilineFunction->None], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"1", "/", "x"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"f_", "[", "g_", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], "'"}], "/.", 
        RowBox[{"x", "\[Rule]", "g"}]}], ")"}], "*", 
      RowBox[{"g", "'"}]}]}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "Although the right\[Dash]hand side of the rule does not evaluate (when \
giving the rule), the result after application evaluates ",
 StyleBox["before",
  FontSlant->"Italic"],
 " the next rule is applied, see the details"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Log", "[", 
     RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[Prime]",
    MultilineFunction->None], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
      RowBox[{"1", "/", "x"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"f_", "[", "g_", "]"}], "'"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], "'"}], "/.", 
         RowBox[{"x", "\[Rule]", "g"}]}], ")"}], "*", 
       RowBox[{"g", "'"}]}]}]}], "}"}]}], "//", "Trace"}]], "Input"],

Cell["After application of the chain rule, we have ", "Text"],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Log", "[", "x", "]"}], "\[Prime]",
      MultilineFunction->None], "/.", "\[InvisibleSpace]", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "x", "]"}], "\[Prime]",
    MultilineFunction->None]}],
  HoldForm]], "Input",
 Evaluatable->False,
 DefaultFormatType->DefaultOutputFormatType,
 FontWeight->"Plain",
 Background->RGBColor[1, 0.900008, 0.900008]],

Cell[TextData[{
 "and now ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Log", "[", "x", "]"}], "'"}], TraditionalForm]]],
 " should be replaced by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "x"}], TraditionalForm]]],
 " ",
 StyleBox["before",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " gets replaced by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Cos", "[", "x", "]"}], TraditionalForm]]],
 " but unfortunately ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " is replaced immediately. Note that ",
 StyleBox["ReplaceRepeated", "Input"],
 " would end up in an infinite loop always applying the chian rule. We give \
an additional condition in order to prevent the chain rule from being applied \
to elementary expressions."
}], "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"Log", "[", 
    RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[Prime]",
   MultilineFunction->None], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"1", "/", "x"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"f_", "[", "g_", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"Hold", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], "'"}], "/.", 
        RowBox[{"x", "\[Rule]", "g"}]}], "]"}], "*", 
      RowBox[{"g", "'"}]}]}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "If we now use ",
 StyleBox["//.", "Input"],
 " we must be careful still because the left\[Dash]hand side of the chain \
rule would apply to elementary expressions, whose differentiation rules are \
unknown or unspecified, like ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Cos", "[", "x", "]"}], TraditionalForm]]],
 " above. We present two solutions:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"Log", "[", 
    RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[Prime]",
   MultilineFunction->None], "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"1", "/", "x"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"f_", "[", 
       RowBox[{"g_", "/;", 
        RowBox[{
         RowBox[{"Depth", "[", "g", "]"}], ">", "1"}]}], "]"}], "'"}], 
     "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"Hold", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], "'"}], "/.", 
        RowBox[{"x", "\[Rule]", "g"}]}], "]"}], "*", 
      RowBox[{"g", "'"}]}]}]}], "}"}]}]], "Input"],

Cell[TextData[{
 "Alternatively, we can give a \"special rule\" for unknown derivatives ",
 StyleBox["before",
  FontSlant->"Italic"],
 " the chain rule. This rule must guarantee to replace the derivative by some \
expression which cannot be rewritten by the chain rule (or other rules that \
follow).",
 " "
}], "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"Log", "[", 
    RowBox[{"Cos", "[", "x", "]"}], "]"}], "\[Prime]",
   MultilineFunction->None], "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"1", "/", "x"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"f_", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{"ToString", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], "'"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"f_", "[", "g_", "]"}], "'"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"Hold", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], "'"}], "/.", 
        RowBox[{"x", "\[Rule]", "g"}]}], "]"}], "*", 
      RowBox[{"g", "'"}]}]}]}], "}"}]}]], "Input"],

Cell["All this together (still incomplete, of course):", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Differentiate", "[", "expr_", "]"}], ":=", 
  RowBox[{"ReleaseHold", "[", 
   RowBox[{
    RowBox[{"expr", "'"}], "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         SuperscriptBox["x", "n_"], ")"}], "'"}], "\[RuleDelayed]", 
       RowBox[{"n", " ", 
        SuperscriptBox["x", 
         RowBox[{"n", "-", "1"}]]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c_", " ", "f_"}], ")"}], "'"}], "/;", 
        RowBox[{"FreeQ", "[", 
         RowBox[{"c", ",", "x"}], "]"}]}], "\[RuleDelayed]", 
       RowBox[{"c", " ", 
        RowBox[{"f", "'"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         SuperscriptBox["\[ExponentialE]", "x"], ")"}], "'"}], 
       "\[RuleDelayed]", 
       SuperscriptBox["\[ExponentialE]", "x"]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
       RowBox[{"1", "/", "x"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
       RowBox[{"Cos", "[", "x", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "x", "]"}], "'"}], "\[RuleDelayed]", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", "x", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"f_", "+", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"f", "'"}], "+", 
        RowBox[{"g", "'"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"f_", "*", "g_"}], ")"}], "'"}], "\[RuleDelayed]", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "g"}], "+", 
        RowBox[{
         RowBox[{"g", "'"}], "f"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f_", "[", 
         RowBox[{"g_", "/;", 
          RowBox[{
           RowBox[{"Depth", "[", "g", "]"}], ">", "1"}]}], "]"}], "'"}], 
       "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"Hold", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], "'"}], "/.", 
          RowBox[{"x", "\[Rule]", "g"}]}], "]"}], "*", 
        RowBox[{"g", "'"}]}]}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Differentiate", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], 
    RowBox[{"Sin", "[", "x", "]"}]}], "+", 
   RowBox[{"2", 
    RowBox[{"Log", "[", 
     RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
   SuperscriptBox["\[ExponentialE]", "x"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "3"], 
     RowBox[{"Sin", "[", "x", "]"}]}], "+", 
    RowBox[{"2", 
     RowBox[{"Log", "[", 
      RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "+", 
    SuperscriptBox["\[ExponentialE]", "x"]}], ",", "x"}], "]"}]], "Input"],

Cell["\<\
Another nice example is \"sorting of lists\", which can be done be \
successively swapping elements that are in the \"wrong order\".\
\>", "Text"],

Cell[BoxData[
 RowBox[{"l", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Random", "[", 
     RowBox[{"Integer", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "10"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "10"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"l", "/.", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pre___", ",", "x_", ",", "y_", ",", "post___"}], "}"}], "/;", 
    RowBox[{"x", "<", "y"}]}], "\[Rule]", 
   RowBox[{"{", 
    RowBox[{"pre", ",", "y", ",", "x", ",", "post"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"l", "//.", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pre___", ",", "x_", ",", "y_", ",", "post___"}], "}"}], "/;", 
    RowBox[{"x", "<", "y"}]}], "\[Rule]", 
   RowBox[{"{", 
    RowBox[{"pre", ",", "y", ",", "x", ",", "post"}], "}"}]}]}]], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Special Topic: Evaluation with Hold\[Dash]Attributes\
\>", "Section"],

Cell[TextData[{
 "Suppose we want to generate the expanded form of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "10"], 
    SuperscriptBox["i", "2"]}], TraditionalForm]]],
 ", i.e. "
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["1", "2"], "+", 
   SuperscriptBox["2", "2"], "+", 
   SuperscriptBox["3", "2"], "+", "\[Ellipsis]", "+", 
   SuperscriptBox["10", "2"]}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
 " in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". ",
 "\nWrite a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " program that returns an expression representing the expanded sum for a \
summand (above: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "2"], TraditionalForm]]],
 ") and a summation range (above: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "10"}], "}"}], TraditionalForm]]],
 ") given as input to the program."
}], "Text"],

Cell["The problem: ", "Text"],

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], "10"], 
  SuperscriptBox["i", "2"]}]], "Input"],

Cell[BoxData[
 RowBox[{"Unevaluated", "[", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "10"], 
   SuperscriptBox["i", "2"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"Unevaluated", "[", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "10"], 
    SuperscriptBox["i", "2"]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], "10"], 
  RowBox[{"Unevaluated", "[", 
   SuperscriptBox["i", "2"], "]"}]}]], "Input"],

Cell[TextData[{
 "Solution: see ",
 ButtonBox["separate notebook",
  BaseStyle->"Hyperlink",
  ButtonData:>{"ExpandSum-Solution.nb", None}],
 "."
}], "Text",
 CellTags->"evalwithHold"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Special Topic: Combining the Features of the Language in a Concrete Example\
\>", "Section"],

Cell[CellGroupData[{

Cell["The Solution of a Linear Diophantine Equation in 2 Variables", \
"Subsection"],

Cell[TextData[{
 "A linear diophantine equation in 2 variables is an equation of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", "x"}], "+", 
     RowBox[{"b", " ", "y"}]}], "\[Equal]", "c"}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"c", "\[Element]", "\[DoubleStruckCapitalZ]"}]}], 
   TraditionalForm]]],
 ". We need to find ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ",", 
    RowBox[{"y", "\[Element]", "\[DoubleStruckCapitalZ]"}]}], 
   TraditionalForm]]],
 ".\nWrite a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " program that computes ",
 StyleBox["all solutions",
  FontSlant->"Italic"],
 " for an equation given as input to the program.",
 "\nDo not use built in commands for solving equations, lookup a solution \
formula for diophantine equations in your lecture notes or on the web. Think \
about the structure of the solutions and choose a mathematically adequate \
representation in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Take care about solvability of the equation, etc."
}], "Text",
 CellChangeTimes->{3.481372545768678*^9}],

Cell[TextData[{
 "Solution: see ",
 ButtonBox["separate notebook",
  BaseStyle->"Hyperlink",
  ButtonData:>{
   "LinearDiophantineEquations-Solution.nb", "LinDiophantEq2Solve"}],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A Program that Verifies the Solution of a Linear Diophantine Equation in 2 \
Variables\
\>", "Subsection"],

Cell["\<\
Write a program that verifies the solution given by the program that solves a \
given linear diophantine equation in 2 variables.\
\>", "Text"],

Cell[TextData[{
 "Solution: see ",
 ButtonBox["separate notebook",
  BaseStyle->"Hyperlink",
  ButtonData:>{
   "LinearDiophantineEquations-Solution.nb", "LinDiophantEq2Verify"}],
 "."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Presentation",
WindowSize->{1024, 700},
WindowMargins->{{4, Automatic}, {Automatic, 49}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "wwindste",
    "Teaching", "ProgrammierenInMathematica", "Skriptum"}, 
  "4-FunctionsAsExpressions.nb.ps", CharacterEncoding -> "iso8859-1"]},
ShowSelection->True,
FrontEndVersion->"7.0 for Linux x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "evalwithHold"->{
  Cell[74163, 2859, 184, 7, 39, "Text",
   CellTags->"evalwithHold"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"evalwithHold", 77211, 2969}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 41, 0, 103, "Title"],
Cell[CellGroupData[{
Cell[611, 24, 118, 4, 93, "Section"],
Cell[732, 30, 149, 5, 70, "Text"],
Cell[884, 37, 147, 4, 70, "Input"],
Cell[1034, 43, 179, 5, 70, "Input"],
Cell[1216, 50, 339, 11, 70, "Input"],
Cell[1558, 63, 216, 6, 70, "Input"],
Cell[1777, 71, 380, 13, 70, "Input"],
Cell[2160, 86, 488, 12, 70, "Text"],
Cell[2651, 100, 207, 6, 70, "Input"],
Cell[2861, 108, 124, 3, 70, "Input"],
Cell[2988, 113, 97, 2, 70, "Input"],
Cell[3088, 117, 100, 2, 70, "Input"],
Cell[3191, 121, 200, 7, 70, "Text"],
Cell[3394, 130, 134, 4, 70, "Input"],
Cell[3531, 136, 277, 12, 70, "Text"],
Cell[3811, 150, 54, 1, 70, "Input"],
Cell[3868, 153, 139, 4, 70, "Input"],
Cell[4010, 159, 201, 4, 70, "Text"],
Cell[4214, 165, 122, 4, 70, "Input"],
Cell[4339, 171, 159, 6, 70, "Input"],
Cell[4501, 179, 105, 3, 70, "Input"],
Cell[4609, 184, 86, 2, 70, "Text"],
Cell[4698, 188, 283, 10, 70, "Input"],
Cell[4984, 200, 274, 10, 70, "Text"],
Cell[5261, 212, 217, 8, 70, "Input"],
Cell[5481, 222, 184, 7, 70, "Input"],
Cell[5668, 231, 77, 2, 70, "Input"],
Cell[5748, 235, 37, 0, 70, "Text"],
Cell[5788, 237, 333, 10, 70, "Input"],
Cell[6124, 249, 502, 16, 70, "Input"],
Cell[6629, 267, 152, 3, 70, "Text"],
Cell[6784, 272, 227, 7, 70, "Input"],
Cell[7014, 281, 90, 2, 70, "Input"],
Cell[7107, 285, 119, 3, 70, "Input"],
Cell[7229, 290, 696, 27, 70, "Text"],
Cell[7928, 319, 70, 1, 70, "Input"],
Cell[8001, 322, 120, 3, 70, "Text"],
Cell[8124, 327, 58, 1, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8219, 333, 52, 0, 65, "Section"],
Cell[CellGroupData[{
Cell[8296, 337, 51, 0, 73, "Subsection"],
Cell[8350, 339, 168, 3, 70, "Text"],
Cell[8521, 344, 139, 4, 70, "Input"],
Cell[8663, 350, 283, 10, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8983, 365, 67, 0, 45, "Subsection"],
Cell[9053, 367, 122, 3, 70, "Text"],
Cell[9178, 372, 236, 7, 70, "Input"],
Cell[9417, 381, 173, 5, 70, "Input"],
Cell[9593, 388, 192, 6, 70, "Input"],
Cell[9788, 396, 95, 2, 70, "Text"],
Cell[9886, 400, 254, 8, 70, "Input"],
Cell[10143, 410, 71, 0, 70, "Text"],
Cell[10217, 412, 278, 9, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[10532, 426, 56, 0, 45, "Subsection"],
Cell[10591, 428, 327, 11, 70, "Input"],
Cell[10921, 441, 122, 3, 70, "Input"],
Cell[11046, 446, 239, 7, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[11322, 458, 82, 1, 45, "Subsection"],
Cell[11407, 461, 91, 2, 70, "Input"],
Cell[11501, 465, 114, 3, 70, "Text"],
Cell[11618, 470, 145, 4, 70, "Input"],
Cell[11766, 476, 265, 8, 70, "Input"],
Cell[12034, 486, 30, 0, 70, "Text"],
Cell[12067, 488, 162, 5, 70, "Input"],
Cell[12232, 495, 209, 6, 70, "Input"],
Cell[12444, 503, 156, 4, 70, "Input"],
Cell[12603, 509, 153, 3, 70, "Text"],
Cell[12759, 514, 168, 5, 70, "Input"],
Cell[12930, 521, 344, 11, 70, "Input"],
Cell[13277, 534, 154, 6, 70, "Text"],
Cell[13434, 542, 329, 11, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13800, 558, 64, 0, 45, "Subsection"],
Cell[13867, 560, 260, 8, 70, "Input"],
Cell[14130, 570, 236, 7, 70, "Input"],
Cell[14369, 579, 147, 6, 70, "Text"],
Cell[14519, 587, 200, 5, 70, "Input"],
Cell[14722, 594, 24, 0, 70, "Text"],
Cell[14749, 596, 210, 6, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[14996, 607, 79, 2, 45, "Subsection"],
Cell[15078, 611, 342, 11, 70, "Text"],
Cell[15423, 624, 150, 4, 70, "Input"],
Cell[15576, 630, 90, 2, 41, "Text"],
Cell[15669, 634, 155, 4, 70, "Input"],
Cell[15827, 640, 220, 7, 72, "Input"],
Cell[16050, 649, 222, 7, 42, "Text"],
Cell[16275, 658, 208, 7, 72, "Input"],
Cell[16486, 667, 30, 0, 41, "Text"],
Cell[16519, 669, 175, 5, 70, "Input"],
Cell[16697, 676, 224, 7, 72, "Input"],
Cell[16924, 685, 130, 4, 104, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17103, 695, 66, 0, 93, "Section"],
Cell[17172, 697, 681, 28, 99, "Text"],
Cell[17856, 727, 91, 2, 70, "Input"],
Cell[17950, 731, 209, 7, 70, "Input"],
Cell[18162, 740, 350, 10, 71, "Text"],
Cell[18515, 752, 82, 2, 70, "Input"],
Cell[18600, 756, 91, 2, 70, "Input"],
Cell[18694, 760, 186, 6, 42, "Text"],
Cell[18883, 768, 90, 2, 70, "Input"],
Cell[18976, 772, 135, 4, 70, "Input"],
Cell[19114, 778, 94, 2, 70, "Input"],
Cell[19211, 782, 203, 8, 42, "Text"],
Cell[19417, 792, 365, 12, 70, "Input"],
Cell[19785, 806, 369, 12, 70, "Input"],
Cell[20157, 820, 35, 0, 41, "Text"],
Cell[CellGroupData[{
Cell[20217, 824, 149, 4, 70, "Input"],
Cell[20369, 830, 235, 8, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20641, 843, 153, 4, 70, "Input"],
Cell[20797, 849, 480, 16, 68, "Output"]
}, Open  ]],
Cell[21292, 868, 146, 4, 70, "Input"],
Cell[21441, 874, 184, 6, 70, "Input"],
Cell[CellGroupData[{
Cell[21650, 884, 41, 0, 73, "Subsection"],
Cell[21694, 886, 368, 16, 70, "Text"],
Cell[22065, 904, 149, 4, 70, "Input"],
Cell[22217, 910, 26, 0, 70, "Text"],
Cell[22246, 912, 201, 7, 70, "DisplayFormula"],
Cell[22450, 921, 154, 4, 70, "Input"],
Cell[22607, 927, 33, 0, 70, "Text"],
Cell[22643, 929, 198, 6, 70, "DisplayFormula"],
Cell[22844, 937, 157, 6, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[23038, 948, 43, 0, 45, "Subsection"],
Cell[23084, 950, 904, 24, 70, "Text"],
Cell[23991, 976, 158, 6, 70, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24198, 988, 53, 0, 93, "Section"],
Cell[24254, 990, 620, 14, 154, "Text"],
Cell[CellGroupData[{
Cell[24899, 1008, 157, 5, 70, "Input"],
Cell[25059, 1015, 199, 6, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25295, 1026, 222, 7, 70, "Input"],
Cell[25520, 1035, 127, 3, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25684, 1043, 131, 2, 70, "Input"],
Cell[25818, 1047, 122, 2, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25977, 1054, 491, 14, 70, "Input"],
Cell[26471, 1070, 172, 4, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26692, 1080, 61, 0, 93, "Section"],
Cell[26756, 1082, 212, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[26993, 1091, 304, 10, 70, "Input"],
Cell[27300, 1103, 310, 10, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27647, 1118, 182, 6, 70, "Input"],
Cell[27832, 1126, 240, 7, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28109, 1138, 150, 3, 70, "Input"],
Cell[28262, 1143, 145, 3, 68, "Output"]
}, Open  ]],
Cell[28422, 1149, 207, 6, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28666, 1160, 39, 0, 93, "Section"],
Cell[CellGroupData[{
Cell[28730, 1164, 74, 0, 73, "Subsection"],
Cell[28807, 1166, 1249, 48, 153, "Text"],
Cell[30059, 1216, 58, 1, 70, "Input"],
Cell[CellGroupData[{
Cell[30142, 1221, 139, 4, 72, "Input"],
Cell[30284, 1227, 93, 2, 68, "Output"]
}, Open  ]],
Cell[30392, 1232, 451, 11, 97, "Text"],
Cell[CellGroupData[{
Cell[30868, 1247, 141, 4, 72, "Input"],
Cell[31012, 1253, 93, 2, 68, "Output"]
}, Open  ]],
Cell[31120, 1258, 133, 3, 70, "Input"],
Cell[CellGroupData[{
Cell[31278, 1265, 156, 3, 70, "Input"],
Cell[31437, 1270, 248, 9, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31722, 1284, 130, 2, 70, "Input"],
Cell[31855, 1288, 134, 3, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32026, 1296, 138, 2, 70, "Input"],
Cell[32167, 1300, 100, 2, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32304, 1307, 353, 8, 72, "Input"],
Cell[32660, 1317, 312, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33009, 1328, 174, 4, 72, "Input"],
Cell[33186, 1334, 124, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33347, 1342, 241, 6, 72, "Input"],
Cell[33591, 1350, 247, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33875, 1362, 123, 2, 70, "Input"],
Cell[34001, 1366, 81, 2, 72, "Output"]
}, Open  ]],
Cell[34097, 1371, 111, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[34233, 1377, 247, 6, 70, "Input"],
Cell[34483, 1385, 174, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34694, 1394, 132, 2, 70, "Input"],
Cell[34829, 1398, 129, 3, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34995, 1406, 757, 17, 70, "Input"],
Cell[35755, 1425, 754, 27, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36546, 1457, 142, 3, 70, "Input"],
Cell[36691, 1462, 122, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36850, 1470, 132, 2, 70, "Input"],
Cell[36985, 1474, 129, 3, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37151, 1482, 132, 2, 70, "Input"],
Cell[37286, 1486, 70, 1, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37393, 1492, 69, 1, 70, "Input"],
Cell[37465, 1495, 70, 1, 68, "Output"]
}, Open  ]],
Cell[37550, 1499, 230, 5, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37817, 1509, 132, 4, 73, "Subsection"],
Cell[37952, 1515, 1036, 23, 251, "Text"],
Cell[CellGroupData[{
Cell[39013, 1542, 227, 8, 70, "Input"],
Cell[39243, 1552, 91, 2, 68, "Output"]
}, Open  ]],
Cell[39349, 1557, 262, 9, 70, "Input"],
Cell[39614, 1568, 356, 13, 47, "Text"],
Cell[CellGroupData[{
Cell[39995, 1585, 281, 10, 74, "Input"],
Cell[40279, 1597, 116, 3, 68, "Output"]
}, Open  ]],
Cell[40410, 1603, 34, 0, 41, "Text"],
Cell[40447, 1605, 90, 2, 70, "Input"],
Cell[40540, 1609, 366, 12, 74, "Input"],
Cell[CellGroupData[{
Cell[40931, 1625, 66, 1, 70, "Input"],
Cell[41000, 1628, 134, 3, 68, "Output"]
}, Open  ]],
Cell[41149, 1634, 72, 1, 70, "Input"],
Cell[41224, 1637, 339, 11, 71, "Text"],
Cell[CellGroupData[{
Cell[41588, 1652, 208, 7, 74, "Input"],
Cell[41799, 1661, 175, 5, 68, "Output"]
}, Open  ]],
Cell[41989, 1669, 188, 4, 69, "Text"],
Cell[42180, 1675, 73, 1, 70, "Input"],
Cell[CellGroupData[{
Cell[42278, 1680, 97, 2, 70, "Input"],
Cell[42378, 1684, 255, 9, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42670, 1698, 215, 7, 74, "Input"],
Cell[42888, 1707, 258, 8, 71, "Output"]
}, Open  ]],
Cell[43161, 1718, 45, 0, 41, "Text"],
Cell[CellGroupData[{
Cell[43231, 1722, 288, 10, 74, "Input"],
Cell[43522, 1734, 116, 3, 68, "Output"]
}, Open  ]],
Cell[43653, 1740, 169, 5, 41, "Text"],
Cell[43825, 1747, 325, 11, 74, "Input"],
Cell[44153, 1760, 511, 20, 75, "Text"],
Cell[44667, 1782, 321, 11, 74, "Input"],
Cell[44991, 1795, 359, 8, 99, "Text"],
Cell[45353, 1805, 78, 2, 70, "Input"],
Cell[45434, 1809, 340, 8, 70, "Text"],
Cell[45777, 1819, 306, 10, 74, "Input"],
Cell[46086, 1831, 165, 4, 42, "Text"],
Cell[46254, 1837, 73, 1, 70, "Input"],
Cell[CellGroupData[{
Cell[46352, 1842, 139, 2, 70, "Input"],
Cell[46494, 1846, 154, 4, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46697, 1856, 73, 0, 73, "Subsection"],
Cell[46773, 1858, 253, 9, 70, "Text"],
Cell[47029, 1869, 238, 8, 70, "Input"],
Cell[47270, 1879, 252, 7, 70, "Text"],
Cell[47525, 1888, 190, 6, 70, "Input"],
Cell[47718, 1896, 258, 9, 70, "Text"],
Cell[47979, 1907, 153, 5, 70, "Input"],
Cell[48135, 1914, 458, 17, 70, "Input"],
Cell[48596, 1933, 787, 25, 70, "Text"],
Cell[49386, 1960, 459, 17, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[49882, 1982, 55, 0, 45, "Subsection"],
Cell[49940, 1984, 314, 6, 70, "Text"],
Cell[50257, 1992, 672, 24, 70, "Input"],
Cell[50932, 2018, 665, 24, 70, "Input"],
Cell[51600, 2044, 636, 24, 70, "Text"],
Cell[52239, 2070, 729, 26, 70, "Input"],
Cell[52971, 2098, 755, 23, 70, "Text"],
Cell[53729, 2123, 594, 20, 70, "Input"],
Cell[54326, 2145, 594, 20, 70, "Input"],
Cell[54923, 2167, 93, 2, 70, "Text"],
Cell[55019, 2171, 656, 22, 70, "Input"],
Cell[55678, 2195, 267, 10, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[55982, 2210, 76, 0, 45, "Subsection"],
Cell[56061, 2212, 590, 17, 70, "Text"],
Cell[56654, 2231, 513, 18, 70, "Input"],
Cell[57170, 2251, 514, 18, 70, "Input"],
Cell[57687, 2271, 1283, 45, 70, "Input"],
Cell[58973, 2318, 144, 3, 70, "Text"],
Cell[59120, 2323, 1283, 45, 70, "Input"],
Cell[60406, 2370, 75, 0, 70, "Text"],
Cell[60484, 2372, 1886, 63, 70, "Input"],
Cell[62373, 2437, 50, 0, 70, "Text"],
Cell[62426, 2439, 629, 21, 70, "Input"],
Cell[63058, 2462, 252, 6, 70, "Text"],
Cell[63313, 2470, 677, 22, 70, "Input"],
Cell[63993, 2494, 61, 0, 70, "Text"],
Cell[64057, 2496, 535, 17, 70, "Input",
 Evaluatable->False],
Cell[64595, 2515, 793, 28, 70, "Text"],
Cell[65391, 2545, 637, 21, 70, "Input"],
Cell[66031, 2568, 377, 10, 70, "Text"],
Cell[66411, 2580, 741, 25, 70, "Input"],
Cell[67155, 2607, 320, 8, 70, "Text"],
Cell[67478, 2617, 833, 27, 70, "Input"],
Cell[68314, 2646, 64, 0, 70, "Text"],
Cell[68381, 2648, 2277, 72, 70, "Input"],
Cell[70661, 2722, 299, 9, 70, "Input"],
Cell[70963, 2733, 318, 10, 70, "Input"],
Cell[71284, 2745, 156, 3, 70, "Text"],
Cell[71443, 2750, 280, 9, 70, "Input"],
Cell[71726, 2761, 287, 8, 70, "Input"],
Cell[72016, 2771, 288, 8, 70, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72353, 2785, 79, 2, 93, "Section"],
Cell[72435, 2789, 254, 9, 39, "Text"],
Cell[72692, 2800, 228, 6, 47, "DisplayFormula"],
Cell[72923, 2808, 509, 19, 103, "Text"],
Cell[73435, 2829, 29, 0, 39, "Text"],
Cell[73467, 2831, 131, 4, 105, "Input"],
Cell[73601, 2837, 172, 5, 105, "Input"],
Cell[73776, 2844, 211, 6, 105, "Input"],
Cell[73990, 2852, 170, 5, 105, "Input"],
Cell[74163, 2859, 184, 7, 39, "Text",
 CellTags->"evalwithHold"]
}, Closed]],
Cell[CellGroupData[{
Cell[74384, 2871, 102, 2, 98, "Section"],
Cell[CellGroupData[{
Cell[74511, 2877, 84, 1, 73, "Subsection"],
Cell[74598, 2880, 1168, 35, 205, "Text"],
Cell[75769, 2917, 195, 7, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76001, 2929, 116, 3, 102, "Subsection"],
Cell[76120, 2934, 153, 3, 69, "Text"],
Cell[76276, 2939, 196, 7, 41, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
